"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdminEndpointsApi = void 0;
const model_1 = require("../model");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
class AdminEndpointsApi extends base_api_1.BaseApi {
    createBasicAuthConfiguration(createRepresentation) {
        (0, assert_1.throwIfNotDefined)(createRepresentation, 'createRepresentation');
        return this.post({
            path: '/api/enterprise/admin/basic-auths',
            bodyParam: createRepresentation,
            returnType: model_1.EndpointBasicAuthRepresentation
        });
    }
    createEndpointConfiguration(representation) {
        (0, assert_1.throwIfNotDefined)(representation, 'representation');
        return this.post({
            path: '/api/enterprise/admin/endpoints',
            bodyParam: representation
        });
    }
    getBasicAuthConfiguration(basicAuthId, tenantId) {
        (0, assert_1.throwIfNotDefined)(basicAuthId, 'basicAuthId');
        (0, assert_1.throwIfNotDefined)(tenantId, 'tenantId');
        const pathParams = {
            basicAuthId
        };
        const queryParams = {
            tenantId
        };
        return this.get({
            path: '/api/enterprise/admin/basic-auths/{basicAuthId}',
            pathParams,
            queryParams,
            returnType: model_1.EndpointBasicAuthRepresentation
        });
    }
    getBasicAuthConfigurations(tenantId) {
        (0, assert_1.throwIfNotDefined)(tenantId, 'tenantId');
        const queryParams = {
            tenantId
        };
        return this.get({
            path: '/api/enterprise/admin/basic-auths',
            queryParams,
            returnType: model_1.EndpointBasicAuthRepresentation
        });
    }
    getEndpointConfiguration(endpointConfigurationId, tenantId) {
        (0, assert_1.throwIfNotDefined)(endpointConfigurationId, 'endpointConfigurationId');
        (0, assert_1.throwIfNotDefined)(tenantId, 'tenantId');
        const pathParams = {
            endpointConfigurationId
        };
        const queryParams = {
            tenantId
        };
        return this.get({
            path: '/api/enterprise/admin/endpoints/{endpointConfigurationId}',
            pathParams,
            queryParams
        });
    }
    getEndpointConfigurations(tenantId) {
        (0, assert_1.throwIfNotDefined)(tenantId, 'tenantId');
        const queryParams = {
            tenantId
        };
        return this.get({
            path: '/api/enterprise/admin/endpoints',
            queryParams
        });
    }
    removeBasicAuthConfiguration(basicAuthId, tenantId) {
        (0, assert_1.throwIfNotDefined)(basicAuthId, 'basicAuthId');
        (0, assert_1.throwIfNotDefined)(tenantId, 'tenantId');
        const pathParams = {
            basicAuthId
        };
        const queryParams = {
            tenantId
        };
        return this.delete({
            path: '/api/enterprise/admin/basic-auths/{basicAuthId}',
            pathParams,
            queryParams
        });
    }
    removeEndpointConfiguration(endpointConfigurationId, tenantId) {
        (0, assert_1.throwIfNotDefined)(endpointConfigurationId, 'endpointConfigurationId');
        (0, assert_1.throwIfNotDefined)(tenantId, 'tenantId');
        const pathParams = {
            endpointConfigurationId
        };
        const queryParams = {
            tenantId
        };
        return this.delete({
            path: '/api/enterprise/admin/endpoints/{endpointConfigurationId}',
            pathParams,
            queryParams
        });
    }
    updateBasicAuthConfiguration(basicAuthId, createRepresentation) {
        (0, assert_1.throwIfNotDefined)(basicAuthId, 'basicAuthId');
        (0, assert_1.throwIfNotDefined)(createRepresentation, 'createRepresentation');
        const pathParams = {
            basicAuthId
        };
        return this.put({
            path: '/api/enterprise/admin/basic-auths/{basicAuthId}',
            pathParams,
            bodyParam: createRepresentation,
            returnType: model_1.EndpointBasicAuthRepresentation
        });
    }
    updateEndpointConfiguration(endpointConfigurationId, representation) {
        (0, assert_1.throwIfNotDefined)(endpointConfigurationId, 'endpointConfigurationId');
        (0, assert_1.throwIfNotDefined)(representation, 'representation');
        const pathParams = {
            endpointConfigurationId
        };
        return this.put({
            path: '/api/enterprise/admin/endpoints/{endpointConfigurationId}',
            pathParams,
            bodyParam: representation
        });
    }
}
exports.AdminEndpointsApi = AdminEndpointsApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/activiti-rest-api/api/adminEndpoints.api.js.map