"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdminTenantsApi = void 0;
const model_1 = require("../model");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
class AdminTenantsApi extends base_api_1.BaseApi {
    createTenant(createTenantRepresentation) {
        (0, assert_1.throwIfNotDefined)(createTenantRepresentation, 'groupId');
        return this.post({
            path: '/api/enterprise/admin/tenants',
            bodyParam: createTenantRepresentation
        });
    }
    deleteTenant(tenantId) {
        (0, assert_1.throwIfNotDefined)(tenantId, 'tenantId');
        const pathParams = {
            tenantId
        };
        return this.delete({
            path: '/api/enterprise/admin/tenants/{tenantId}',
            pathParams
        });
    }
    getTenantEvents(tenantId) {
        (0, assert_1.throwIfNotDefined)(tenantId, 'tenantId');
        const pathParams = {
            tenantId
        };
        return this.get({
            path: '/api/enterprise/admin/tenants/{tenantId}/events',
            pathParams,
            returnType: model_1.TenantEvent
        });
    }
    getTenantLogo(tenantId) {
        (0, assert_1.throwIfNotDefined)(tenantId, 'tenantId');
        const pathParams = {
            tenantId
        };
        return this.get({
            path: '/api/enterprise/admin/tenants/{tenantId}/logo',
            pathParams
        });
    }
    getTenant(tenantId) {
        (0, assert_1.throwIfNotDefined)(tenantId, 'tenantId');
        const pathParams = {
            tenantId
        };
        return this.get({
            path: '/api/enterprise/admin/tenants/{tenantId}',
            pathParams,
            returnType: model_1.TenantRepresentation
        });
    }
    getTenants() {
        return this.get({
            path: '/api/enterprise/admin/tenants'
        });
    }
    update(tenantId, createTenantRepresentation) {
        (0, assert_1.throwIfNotDefined)(tenantId, 'tenantId');
        (0, assert_1.throwIfNotDefined)(createTenantRepresentation, 'createTenantRepresentation');
        const pathParams = {
            tenantId
        };
        return this.put({
            path: '/api/enterprise/admin/tenants/{tenantId}',
            pathParams,
            bodyParam: createTenantRepresentation,
            returnType: model_1.TenantRepresentation
        });
    }
    uploadTenantLogo(tenantId, file) {
        (0, assert_1.throwIfNotDefined)(tenantId, 'tenantId');
        (0, assert_1.throwIfNotDefined)(file, 'file');
        const pathParams = {
            tenantId
        };
        const formParams = {
            file
        };
        return this.post({
            path: '/api/enterprise/admin/tenants/{tenantId}/logo',
            pathParams,
            formParams,
            contentTypes: ['multipart/form-data'],
            returnType: model_1.ImageUploadRepresentation
        });
    }
}
exports.AdminTenantsApi = AdminTenantsApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/activiti-rest-api/api/adminTenants.api.js.map