"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdminUsersApi = void 0;
const model_1 = require("../model");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
class AdminUsersApi extends base_api_1.BaseApi {
    bulkUpdateUsers(update) {
        (0, assert_1.throwIfNotDefined)(update, 'update');
        return this.put({
            path: '/api/enterprise/admin/users',
            bodyParam: update
        });
    }
    createNewUser(userRepresentation) {
        (0, assert_1.throwIfNotDefined)(userRepresentation, 'userRepresentation');
        return this.post({
            path: '/api/enterprise/admin/users',
            bodyParam: userRepresentation,
            returnType: model_1.UserRepresentation
        });
    }
    getUser(userId, opts) {
        (0, assert_1.throwIfNotDefined)(userId, 'userId');
        const pathParams = {
            userId
        };
        return this.get({
            path: '/api/enterprise/admin/users/{userId}',
            pathParams,
            queryParams: opts
        });
    }
    getUsers(opts) {
        return this.get({
            path: '/api/enterprise/admin/users',
            queryParams: opts
        });
    }
    updateUserDetails(userId, userRepresentation) {
        (0, assert_1.throwIfNotDefined)(userId, 'userId');
        (0, assert_1.throwIfNotDefined)(userRepresentation, 'userRepresentation');
        const pathParams = {
            userId
        };
        return this.put({
            path: '/api/enterprise/admin/users/{userId}',
            pathParams,
            bodyParam: userRepresentation
        });
    }
}
exports.AdminUsersApi = AdminUsersApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/activiti-rest-api/api/adminUsers.api.js.map