"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.AppDefinitionsApi = void 0;
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
class AppDefinitionsApi extends base_api_1.BaseApi {
    deleteAppDefinition(appDefinitionId) {
        (0, assert_1.throwIfNotDefined)(appDefinitionId, 'appDefinitionId');
        const pathParams = {
            appDefinitionId
        };
        return this.delete({
            path: '/api/enterprise/app-definitions/{appDefinitionId}',
            pathParams
        });
    }
    exportAppDefinition(modelId) {
        (0, assert_1.throwIfNotDefined)(modelId, 'modelId');
        const pathParams = {
            modelId
        };
        const contentTypes = ['application/json'];
        const accepts = ['application/json', 'application/zip'];
        return this.get({
            path: '/api/enterprise/app-definitions/{modelId}/export',
            pathParams,
            contentTypes,
            accepts
        });
    }
    getAppDefinition(modelId) {
        (0, assert_1.throwIfNotDefined)(modelId, 'modelId');
        const pathParams = {
            modelId
        };
        return this.get({
            path: '/api/enterprise/app-definitions/{modelId}',
            pathParams
        });
    }
    importAndPublishApp(file, opts) {
        (0, assert_1.throwIfNotDefined)(file, 'file');
        const formParams = {
            file
        };
        const queryParams = {
            renewIdmEntries: opts === null || opts === void 0 ? void 0 : opts.renewIdmEntries
        };
        return this.post({
            path: '/api/enterprise/app-definitions/publish-app',
            formParams,
            queryParams,
            contentTypes: ['multipart/form-data']
        });
    }
    importAppDefinition(file, opts) {
        (0, assert_1.throwIfNotDefined)(file, 'file');
        const formParams = {
            file
        };
        return this.post({
            path: '/api/enterprise/app-definitions/import',
            queryParams: opts,
            formParams,
            contentTypes: ['multipart/form-data']
        });
    }
    publishAppDefinition(modelId, publishModel) {
        (0, assert_1.throwIfNotDefined)(modelId, 'modelId');
        (0, assert_1.throwIfNotDefined)(publishModel, 'publishModel');
        const pathParams = {
            modelId
        };
        return this.post({
            path: '/api/enterprise/app-definitions/{modelId}/publish',
            pathParams,
            bodyParam: publishModel
        });
    }
    updateAppDefinition(modelId, updatedModel) {
        (0, assert_1.throwIfNotDefined)(modelId, 'modelId');
        (0, assert_1.throwIfNotDefined)(updatedModel, 'updatedModel');
        const pathParams = {
            modelId
        };
        if (!updatedModel['appDefinition']) {
            const formParams = {
                file: updatedModel
            };
            return this.post({
                path: '/api/enterprise/app-definitions/{modelId}/import',
                pathParams,
                formParams,
                bodyParam: updatedModel,
                contentTypes: ['multipart/form-data']
            });
        }
        else {
            return this.put({
                path: '/api/enterprise/app-definitions/{modelId}',
                pathParams,
                bodyParam: updatedModel
            });
        }
    }
}
exports.AppDefinitionsApi = AppDefinitionsApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/activiti-rest-api/api/appDefinitions.api.js.map