"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ActivitiCommentsApi = void 0;
const commentRepresentation_1 = require("../model/commentRepresentation");
const resultListDataRepresentationCommentRepresentation_1 = require("../model/resultListDataRepresentationCommentRepresentation");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
class ActivitiCommentsApi extends base_api_1.BaseApi {
    addProcessInstanceComment(commentRequest, processInstanceId) {
        (0, assert_1.throwIfNotDefined)(commentRequest, 'commentRequest');
        (0, assert_1.throwIfNotDefined)(processInstanceId, 'processInstanceId');
        const pathParams = {
            processInstanceId
        };
        return this.post({
            path: '/api/enterprise/process-instances/{processInstanceId}/comments',
            pathParams,
            bodyParam: commentRequest,
            returnType: commentRepresentation_1.CommentRepresentation
        });
    }
    addTaskComment(commentRequest, taskId) {
        (0, assert_1.throwIfNotDefined)(commentRequest, 'commentRequest');
        (0, assert_1.throwIfNotDefined)(taskId, 'taskId');
        const pathParams = {
            taskId
        };
        return this.post({
            path: '/api/enterprise/tasks/{taskId}/comments',
            pathParams,
            bodyParam: commentRequest,
            returnType: commentRepresentation_1.CommentRepresentation
        });
    }
    getProcessInstanceComments(processInstanceId, opts) {
        (0, assert_1.throwIfNotDefined)(processInstanceId, 'processInstanceId');
        const pathParams = {
            processInstanceId
        };
        return this.get({
            path: '/api/enterprise/process-instances/{processInstanceId}/comments',
            pathParams,
            queryParams: opts,
            returnType: resultListDataRepresentationCommentRepresentation_1.ResultListDataRepresentationCommentRepresentation
        });
    }
    getTaskComments(taskId, opts) {
        (0, assert_1.throwIfNotDefined)(taskId, 'taskId');
        const pathParams = {
            taskId
        };
        return this.get({
            path: '/api/enterprise/tasks/{taskId}/comments',
            pathParams,
            queryParams: opts,
            returnType: resultListDataRepresentationCommentRepresentation_1.ResultListDataRepresentationCommentRepresentation
        });
    }
}
exports.ActivitiCommentsApi = ActivitiCommentsApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/activiti-rest-api/api/comments.api.js.map