"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.FormModelsApi = void 0;
const model_1 = require("../model");
const base_api_1 = require("./base.api");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
const assert_1 = require("../../../assert");
class FormModelsApi extends base_api_1.BaseApi {
    getFormEditorJson(formId) {
        (0, assert_1.throwIfNotDefined)(formId, 'formId');
        const pathParams = {
            formId
        };
        return this.get({
            path: '/api/enterprise/forms/{formId}/editorJson',
            pathParams
        });
    }
    getFormHistory(formId, formHistoryId) {
        (0, assert_1.throwIfNotDefined)(formId, 'formId');
        (0, assert_1.throwIfNotDefined)(formHistoryId, 'formHistoryId');
        const pathParams = {
            formId,
            formHistoryId
        };
        return this.get({
            path: '/api/enterprise/editor/form-models/{formId}/history/{formHistoryId}',
            pathParams,
            returnType: model_1.FormRepresentation
        });
    }
    getForm(formId) {
        (0, assert_1.throwIfNotDefined)(formId, 'formId');
        const pathParams = {
            formId
        };
        return this.get({
            path: '/api/enterprise/editor/form-models/{formId}',
            pathParams,
            returnType: model_1.FormRepresentation
        });
    }
    getForms(input) {
        if (typeof input === 'string') {
            const queryParams = {
                formId: (0, alfrescoApiClient_1.buildCollectionParam)(input, 'multi')
            };
            return this.get({
                path: '/api/enterprise/editor/form-models/values',
                queryParams,
                returnType: model_1.FormRepresentation
            });
        }
        else if (typeof input === 'object') {
            return this.get({
                path: '/api/enterprise/forms',
                queryParams: input
            });
        }
        else {
            return this.get({
                path: '/api/enterprise/editor/form-models',
                returnType: model_1.ResultListDataRepresentationFormRepresentation
            });
        }
    }
    saveForm(formId, saveRepresentation) {
        (0, assert_1.throwIfNotDefined)(formId, 'formId');
        (0, assert_1.throwIfNotDefined)(saveRepresentation, 'saveRepresentation');
        const pathParams = {
            formId
        };
        return this.put({
            path: '/api/enterprise/editor/form-models/{formId}',
            pathParams,
            bodyParam: saveRepresentation,
            returnType: model_1.FormRepresentation
        });
    }
    validateModel(formId, saveRepresentation) {
        (0, assert_1.throwIfNotDefined)(formId, 'formId');
        (0, assert_1.throwIfNotDefined)(saveRepresentation, 'saveRepresentation');
        const pathParams = {
            formId
        };
        return this.get({
            path: '/api/enterprise/editor/form-models/{formId}/validate',
            pathParams,
            bodyParam: saveRepresentation
        });
    }
}
exports.FormModelsApi = FormModelsApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/activiti-rest-api/api/formModels.api.js.map