"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.IntegrationAlfrescoCloudApi = void 0;
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
class IntegrationAlfrescoCloudApi extends base_api_1.BaseApi {
    confirmAuthorisation(code) {
        (0, assert_1.throwIfNotDefined)(code, 'code');
        const queryParams = {
            code
        };
        return this.get({
            path: '/api/enterprise/integration/alfresco-cloud/confirm-auth-request',
            queryParams,
            accepts: ['text/html']
        });
    }
    getAllNetworks() {
        return this.get({
            path: '/api/enterprise/integration/alfresco-cloud/networks'
        });
    }
    getAllSites(networkId) {
        (0, assert_1.throwIfNotDefined)(networkId, 'networkId');
        const pathParams = {
            networkId
        };
        return this.get({
            path: '/api/enterprise/integration/alfresco-cloud/networks/{networkId}/sites',
            pathParams
        });
    }
    getContentInFolderPath(networkId, opts) {
        (0, assert_1.throwIfNotDefined)(networkId, 'networkId');
        const pathParams = {
            networkId
        };
        return this.get({
            path: '/api/enterprise/integration/alfresco-cloud/networks/{networkId}/sites/{siteId}/folderpath/{folderPath}/content',
            pathParams,
            queryParams: opts
        });
    }
    getContentInFolder(networkId, folderId) {
        (0, assert_1.throwIfNotDefined)(networkId, 'networkId');
        (0, assert_1.throwIfNotDefined)(folderId, 'folderId');
        const pathParams = {
            networkId,
            folderId
        };
        return this.get({
            path: '/api/enterprise/integration/alfresco-cloud/networks/{networkId}/folders/{folderId}/content',
            pathParams
        });
    }
    getContentInSite(networkId, siteId) {
        (0, assert_1.throwIfNotDefined)(networkId, 'networkId');
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        const pathParams = {
            networkId,
            siteId
        };
        return this.get({
            path: '/api/enterprise/integration/alfresco-cloud/networks/{networkId}/sites/{siteId}/content',
            pathParams
        });
    }
}
exports.IntegrationAlfrescoCloudApi = IntegrationAlfrescoCloudApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/activiti-rest-api/api/integrationAlfrescoCloud.api.js.map