"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.IntegrationAlfrescoOnPremiseApi = void 0;
const model_1 = require("../model");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
class IntegrationAlfrescoOnPremiseApi extends base_api_1.BaseApi {
    getAllSites(repositoryId) {
        (0, assert_1.throwIfNotDefined)(repositoryId, 'networkId');
        const pathParams = {
            repositoryId
        };
        return this.get({
            path: '/api/enterprise/integration/alfresco/{repositoryId}/sites',
            pathParams
        });
    }
    getContentInFolderPath(repositoryId, siteId, folderPath) {
        (0, assert_1.throwIfNotDefined)(repositoryId, 'networkId');
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        (0, assert_1.throwIfNotDefined)(folderPath, 'folderPath');
        const pathParams = {
            repositoryId,
            siteId,
            folderPath
        };
        return this.get({
            path: '/api/enterprise/rest/integration/alfresco/{repositoryId}/sites/{siteId}/folderpath/{folderPath}/content',
            pathParams
        });
    }
    getContentInFolder(repositoryId, folderId) {
        (0, assert_1.throwIfNotDefined)(repositoryId, 'networkId');
        (0, assert_1.throwIfNotDefined)(folderId, 'folderId');
        const pathParams = {
            repositoryId,
            folderId
        };
        return this.get({
            path: '/api/enterprise/integration/alfresco/{repositoryId}/folders/{folderId}/content',
            pathParams
        });
    }
    getContentInSite(repositoryId, siteId) {
        (0, assert_1.throwIfNotDefined)(repositoryId, 'networkId');
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        const pathParams = {
            repositoryId,
            siteId
        };
        return this.get({
            path: '/api/enterprise/integration/alfresco/{repositoryId}/sites/{siteId}/content',
            pathParams
        });
    }
    getRepositories(opts) {
        return this.get({
            path: '/api/enterprise/profile/accounts/alfresco',
            queryParams: opts,
            returnType: model_1.ResultListDataRepresentationAlfrescoEndpointRepresentation
        });
    }
}
exports.IntegrationAlfrescoOnPremiseApi = IntegrationAlfrescoOnPremiseApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/activiti-rest-api/api/integrationAlfrescoOnPremise.api.js.map