"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ModelsHistoryApi = void 0;
const modelRepresentation_1 = require("../model/modelRepresentation");
const resultListDataRepresentationModelRepresentation_1 = require("../model/resultListDataRepresentationModelRepresentation");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
class ModelsHistoryApi extends base_api_1.BaseApi {
    getModelHistoryCollection(modelId, opts) {
        (0, assert_1.throwIfNotDefined)(modelId, 'modelId');
        const pathParams = {
            modelId
        };
        const queryParams = {
            includeLatestVersion: opts === null || opts === void 0 ? void 0 : opts.includeLatestVersion
        };
        return this.get({
            path: '/api/enterprise/models/{modelId}/history',
            pathParams,
            queryParams,
            returnType: resultListDataRepresentationModelRepresentation_1.ResultListDataRepresentationModelRepresentation
        });
    }
    getProcessModelHistory(modelId, modelHistoryId) {
        (0, assert_1.throwIfNotDefined)(modelId, 'modelId');
        (0, assert_1.throwIfNotDefined)(modelHistoryId, 'modelHistoryId');
        const pathParams = {
            modelId,
            modelHistoryId
        };
        return this.get({
            path: '/api/enterprise/models/{modelId}/history/{modelHistoryId}',
            pathParams,
            returnType: modelRepresentation_1.ModelRepresentation
        });
    }
}
exports.ModelsHistoryApi = ModelsHistoryApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/activiti-rest-api/api/modelsHistory.api.js.map