"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProcessInstancesApi = void 0;
const model_1 = require("../model");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
class ProcessInstancesApi extends base_api_1.BaseApi {
    activateProcessInstance(processInstanceId) {
        (0, assert_1.throwIfNotDefined)(processInstanceId, 'processInstanceId');
        const pathParams = {
            processInstanceId
        };
        return this.put({
            path: '/api/enterprise/process-instances/{processInstanceId}/activate',
            pathParams,
            returnType: model_1.ProcessInstanceRepresentation
        });
    }
    createIdentityLink(processInstanceId, identityLinkRepresentation) {
        (0, assert_1.throwIfNotDefined)(processInstanceId, 'processInstanceId');
        (0, assert_1.throwIfNotDefined)(identityLinkRepresentation, 'identityLinkRepresentation');
        const pathParams = {
            processInstanceId
        };
        return this.post({
            path: '/api/enterprise/process-instances/{processInstanceId}/identitylinks',
            pathParams,
            bodyParam: identityLinkRepresentation
        });
    }
    deleteIdentityLink(processInstanceId, family, identityId, type) {
        (0, assert_1.throwIfNotDefined)(processInstanceId, 'processInstanceId');
        (0, assert_1.throwIfNotDefined)(family, 'family');
        (0, assert_1.throwIfNotDefined)(identityId, 'identityId');
        (0, assert_1.throwIfNotDefined)(type, 'type');
        const pathParams = {
            processInstanceId,
            family,
            identityId,
            type
        };
        return this.delete({
            path: '/api/enterprise/process-instances/{processInstanceId}/identitylinks/{family}/{identityId}/{type}',
            pathParams
        });
    }
    deleteProcessInstance(processInstanceId) {
        (0, assert_1.throwIfNotDefined)(processInstanceId, 'processInstanceId');
        const pathParams = {
            processInstanceId
        };
        return this.delete({
            path: '/api/enterprise/process-instances/{processInstanceId}',
            pathParams
        });
    }
    filterProcessInstances(filterRequest) {
        (0, assert_1.throwIfNotDefined)(filterRequest, 'filterRequest');
        return this.post({
            path: '/api/enterprise/process-instances/filter',
            bodyParam: filterRequest,
            returnType: model_1.ResultListDataRepresentationProcessInstanceRepresentation
        });
    }
    getHistoricProcessInstanceDecisionTasks(processInstanceId) {
        (0, assert_1.throwIfNotDefined)(processInstanceId, 'processInstanceId');
        const pathParams = {
            processInstanceId
        };
        return this.get({
            path: '/api/enterprise/process-instances/{processInstanceId}/decision-tasks',
            pathParams,
            returnType: model_1.ResultListDataRepresentationDecisionTaskRepresentation
        });
    }
    getHistoricProcessInstanceVariables(processInstanceId) {
        (0, assert_1.throwIfNotDefined)(processInstanceId, 'processInstanceId');
        const pathParams = {
            processInstanceId
        };
        return this.get({
            path: '/api/enterprise/process-instances/{processInstanceId}/historic-variables',
            pathParams
        });
    }
    getHistoricProcessInstances(queryRequest) {
        (0, assert_1.throwIfNotDefined)(queryRequest, 'queryRequest');
        return this.post({
            path: '/api/enterprise/historic-process-instances/query',
            bodyParam: queryRequest,
            returnType: model_1.ResultListDataRepresentationProcessInstanceRepresentation
        });
    }
    getIdentityLinkType(processInstanceId, family, identityId, type) {
        (0, assert_1.throwIfNotDefined)(processInstanceId, 'processInstanceId');
        (0, assert_1.throwIfNotDefined)(family, 'family');
        (0, assert_1.throwIfNotDefined)(identityId, 'identityId');
        (0, assert_1.throwIfNotDefined)(type, 'type');
        const pathParams = {
            processInstanceId,
            family,
            identityId,
            type
        };
        return this.get({
            path: '/api/enterprise/process-instances/{processInstanceId}/identitylinks/{family}/{identityId}/{type}',
            pathParams
        });
    }
    getIdentityLinksForFamily(processInstanceId, family) {
        (0, assert_1.throwIfNotDefined)(processInstanceId, 'processInstanceId');
        (0, assert_1.throwIfNotDefined)(family, 'family');
        const pathParams = {
            processInstanceId,
            family
        };
        return this.get({
            path: '/api/enterprise/process-instances/{processInstanceId}/identitylinks/{family}',
            pathParams
        });
    }
    getIdentityLinks(processInstanceId) {
        (0, assert_1.throwIfNotDefined)(processInstanceId, 'processInstanceId');
        const pathParams = {
            processInstanceId
        };
        return this.get({
            path: '/api/enterprise/process-instances/{processInstanceId}/identitylinks',
            pathParams
        });
    }
    getProcessInstanceContent(processInstanceId) {
        (0, assert_1.throwIfNotDefined)(processInstanceId, 'processInstanceId');
        const pathParams = {
            processInstanceId
        };
        return this.get({
            path: '/api/enterprise/process-instances/{processInstanceId}/field-content',
            pathParams,
            returnType: model_1.ResultListDataRepresentationProcessContentRepresentation
        });
    }
    getProcessInstanceDiagram(processInstanceId) {
        (0, assert_1.throwIfNotDefined)(processInstanceId, 'processInstanceId');
        const pathParams = {
            processInstanceId
        };
        const accepts = ['image/png'];
        return this.get({
            path: '/api/enterprise/process-instances/{processInstanceId}/diagram',
            pathParams,
            accepts
        });
    }
    getProcessInstanceStartForm(processInstanceId) {
        (0, assert_1.throwIfNotDefined)(processInstanceId, 'processInstanceId');
        const pathParams = {
            processInstanceId
        };
        return this.get({
            path: '/api/enterprise/process-instances/{processInstanceId}/start-form',
            pathParams
        });
    }
    getProcessInstance(processInstanceId) {
        (0, assert_1.throwIfNotDefined)(processInstanceId, 'processInstanceId');
        const pathParams = {
            processInstanceId
        };
        return this.get({
            path: '/api/enterprise/process-instances/{processInstanceId}',
            pathParams,
            returnType: model_1.ProcessInstanceRepresentation
        });
    }
    getProcessInstances(processInstancesQuery) {
        (0, assert_1.throwIfNotDefined)(processInstancesQuery, 'processInstancesQuery');
        return this.post({
            path: '/api/enterprise/process-instances/query',
            bodyParam: processInstancesQuery,
            returnType: model_1.ResultListDataRepresentationProcessInstanceRepresentation
        });
    }
    getTaskAuditLog(processInstanceId) {
        (0, assert_1.throwIfNotDefined)(processInstanceId, 'processInstanceId');
        const pathParams = {
            processInstanceId
        };
        return this.get({
            path: '/api/enterprise/process-instances/{processInstanceId}/audit-log',
            pathParams
        });
    }
    getProcessAuditPdf(processInstanceId) {
        (0, assert_1.throwIfNotDefined)(processInstanceId, 'processInstanceId');
        const pathParams = {
            processInstanceId
        };
        const responseType = 'blob';
        return this.get({
            path: '/app/rest/process-instances/{processInstanceId}/audit',
            pathParams,
            responseType
        });
    }
    startNewProcessInstance(startRequest) {
        (0, assert_1.throwIfNotDefined)(startRequest, 'startRequest');
        return this.post({
            path: '/api/enterprise/process-instances',
            bodyParam: startRequest,
            returnType: model_1.ProcessInstanceRepresentation
        });
    }
    suspendProcessInstance(processInstanceId) {
        (0, assert_1.throwIfNotDefined)(processInstanceId, 'processInstanceId');
        const pathParams = {
            processInstanceId
        };
        return this.put({
            path: '/api/enterprise/process-instances/{processInstanceId}/suspend',
            pathParams,
            returnType: model_1.ProcessInstanceRepresentation
        });
    }
}
exports.ProcessInstancesApi = ProcessInstancesApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/activiti-rest-api/api/processInstances.api.js.map