"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ReportApi = void 0;
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
class ReportApi extends base_api_1.BaseApi {
    createDefaultReports() {
        return this.post({
            path: '/app/rest/reporting/default-reports'
        });
    }
    getTasksByProcessDefinitionId(reportId, processDefinitionId) {
        (0, assert_1.throwIfNotDefined)(reportId, 'reportId');
        (0, assert_1.throwIfNotDefined)(processDefinitionId, 'processDefinitionId');
        const pathParams = {
            reportId
        };
        const queryParams = {
            processDefinitionId
        };
        return this.get({
            path: '/app/rest/reporting/report-params/{reportId}/tasks',
            pathParams,
            queryParams
        });
    }
    getReportsByParams(reportId, bodyParam) {
        (0, assert_1.throwIfNotDefined)(reportId, 'reportId');
        const pathParams = {
            reportId
        };
        return this.post({
            path: '/app/rest/reporting/report-params/{reportId}',
            pathParams,
            bodyParam
        });
    }
    getProcessDefinitions() {
        return this.get({
            path: '/app/rest/reporting/process-definitions'
        });
    }
    getReportParams(reportId) {
        (0, assert_1.throwIfNotDefined)(reportId, 'reportId');
        const pathParams = {
            reportId
        };
        return this.get({
            path: '/app/rest/reporting/report-params/{reportId}',
            pathParams
        });
    }
    getReportList() {
        return this.get({
            path: '/app/rest/reporting/reports'
        });
    }
    updateReport(reportId, name) {
        (0, assert_1.throwIfNotDefined)(reportId, 'reportId');
        const postBody = {
            name
        };
        const pathParams = {
            reportId
        };
        return this.put({
            path: '/app/rest/reporting/reports/{reportId}',
            pathParams,
            bodyParam: postBody
        });
    }
    exportToCsv(reportId, bodyParam) {
        (0, assert_1.throwIfNotDefined)(reportId, 'reportId');
        (0, assert_1.throwIfNotDefined)(bodyParam, 'bodyParam');
        (0, assert_1.throwIfNotDefined)(bodyParam.reportName, 'reportName');
        const pathParams = {
            reportId
        };
        return this.post({
            path: '/app/rest/reporting/reports/{reportId}/export-to-csv',
            pathParams,
            bodyParam
        });
    }
    saveReport(reportId, opts) {
        (0, assert_1.throwIfNotDefined)(reportId, 'reportId');
        (0, assert_1.throwIfNotDefined)(opts, 'opts');
        (0, assert_1.throwIfNotDefined)(opts.reportName, 'reportName');
        const bodyParam = {
            reportName: opts.reportName,
            __reportName: opts.reportName
        };
        const pathParams = {
            reportId
        };
        return this.post({
            path: '/app/rest/reporting/reports/{reportId}',
            pathParams,
            bodyParam
        });
    }
    deleteReport(reportId) {
        (0, assert_1.throwIfNotDefined)(reportId, 'reportId');
        const pathParams = {
            reportId
        };
        return this.delete({
            path: '/app/rest/reporting/reports/{reportId}',
            pathParams
        });
    }
}
exports.ReportApi = ReportApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/activiti-rest-api/api/report.api.js.map