"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.RuntimeAppDeploymentsApi = void 0;
const appDeploymentRepresentation_1 = require("../model/appDeploymentRepresentation");
const resultListDataRepresentationAppDeploymentRepresentation_1 = require("../model/resultListDataRepresentationAppDeploymentRepresentation");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
class RuntimeAppDeploymentsApi extends base_api_1.BaseApi {
    deleteAppDeployment(appDeploymentId) {
        (0, assert_1.throwIfNotDefined)(appDeploymentId, 'appDeploymentId');
        const pathParams = {
            appDeploymentId
        };
        return this.delete({
            path: '/api/enterprise/runtime-app-deployments/{appDeploymentId}',
            pathParams
        });
    }
    exportAppDefinition(deploymentId) {
        (0, assert_1.throwIfNotDefined)(deploymentId, 'deploymentId');
        const pathParams = {
            deploymentId
        };
        const accepts = ['application/zip'];
        return this.get({
            path: '/api/enterprise/export-app-deployment/{deploymentId}',
            pathParams,
            accepts
        });
    }
    getAppDefinitions(opts) {
        return this.get({
            path: '/api/enterprise/runtime-app-deployments',
            queryParams: opts,
            returnType: resultListDataRepresentationAppDeploymentRepresentation_1.ResultListDataRepresentationAppDeploymentRepresentation
        });
    }
    getAppDeployment(appDeploymentId) {
        (0, assert_1.throwIfNotDefined)(appDeploymentId, 'appDeploymentId');
        const pathParams = {
            appDeploymentId
        };
        return this.get({
            path: '/api/enterprise/runtime-app-deployments/{appDeploymentId}',
            pathParams,
            returnType: appDeploymentRepresentation_1.AppDeploymentRepresentation
        });
    }
    getRuntimeAppDeploymentByDeployment(opts) {
        return this.get({
            path: '/api/enterprise/runtime-app-deployment',
            queryParams: opts,
            returnType: appDeploymentRepresentation_1.AppDeploymentRepresentation
        });
    }
}
exports.RuntimeAppDeploymentsApi = RuntimeAppDeploymentsApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/activiti-rest-api/api/runtimeAppDeployments.api.js.map