"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.TaskActionsApi = void 0;
const model_1 = require("../model");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
class TaskActionsApi extends base_api_1.BaseApi {
    assignTask(taskId, userIdentifier) {
        (0, assert_1.throwIfNotDefined)(taskId, 'taskId');
        (0, assert_1.throwIfNotDefined)(userIdentifier, 'userIdentifier');
        const pathParams = {
            taskId
        };
        return this.put({
            path: '/api/enterprise/tasks/{taskId}/action/assign',
            pathParams,
            bodyParam: userIdentifier,
            returnType: model_1.TaskRepresentation
        });
    }
    attachForm(taskId, formIdentifier) {
        (0, assert_1.throwIfNotDefined)(taskId, 'taskId');
        (0, assert_1.throwIfNotDefined)(formIdentifier, 'formIdentifier');
        const pathParams = {
            taskId
        };
        return this.put({
            path: '/api/enterprise/tasks/{taskId}/action/attach-form',
            pathParams,
            bodyParam: formIdentifier
        });
    }
    claimTask(taskId) {
        (0, assert_1.throwIfNotDefined)(taskId, 'taskId');
        const pathParams = {
            taskId
        };
        return this.put({
            path: '/api/enterprise/tasks/{taskId}/action/claim',
            pathParams
        });
    }
    completeTask(taskId) {
        (0, assert_1.throwIfNotDefined)(taskId, 'taskId');
        const pathParams = {
            taskId
        };
        return this.put({
            path: '/api/enterprise/tasks/{taskId}/action/complete',
            pathParams
        });
    }
    delegateTask(taskId, userIdentifier) {
        (0, assert_1.throwIfNotDefined)(taskId, 'taskId');
        (0, assert_1.throwIfNotDefined)(userIdentifier, 'userIdentifier');
        const pathParams = {
            taskId
        };
        return this.put({
            path: '/api/enterprise/tasks/{taskId}/action/delegate',
            pathParams,
            bodyParam: userIdentifier
        });
    }
    involveGroup(taskId, groupId) {
        (0, assert_1.throwIfNotDefined)(taskId, 'taskId');
        (0, assert_1.throwIfNotDefined)(groupId, 'groupId');
        const pathParams = {
            taskId,
            groupId
        };
        return this.post({
            path: '/api/enterprise/tasks/{taskId}/groups/{groupId}',
            pathParams
        });
    }
    involveUser(taskId, userIdentifier) {
        (0, assert_1.throwIfNotDefined)(taskId, 'taskId');
        (0, assert_1.throwIfNotDefined)(userIdentifier, 'userIdentifier');
        const pathParams = {
            taskId
        };
        return this.put({
            path: '/api/enterprise/tasks/{taskId}/action/involve',
            pathParams,
            bodyParam: userIdentifier
        });
    }
    removeForm(taskId) {
        (0, assert_1.throwIfNotDefined)(taskId, 'taskId');
        const pathParams = {
            taskId
        };
        return this.delete({
            path: '/api/enterprise/tasks/{taskId}/action/remove-form',
            pathParams
        });
    }
    removeInvolvedUser(taskId, identifier) {
        (0, assert_1.throwIfNotDefined)(taskId, 'taskId');
        (0, assert_1.throwIfNotDefined)(identifier, 'identifier');
        const pathParams = {
            taskId,
            identifier
        };
        if (identifier instanceof String) {
            return this.delete({
                path: '/api/enterprise/tasks/{taskId}/groups/{groupId}',
                pathParams
            });
        }
        else {
            return this.put({
                path: '/api/enterprise/tasks/{taskId}/action/remove-involved',
                pathParams,
                bodyParam: identifier
            });
        }
    }
    resolveTask(taskId) {
        (0, assert_1.throwIfNotDefined)(taskId, 'taskId');
        const pathParams = {
            taskId
        };
        return this.put({
            path: '/api/enterprise/tasks/{taskId}/action/resolve',
            pathParams
        });
    }
    unclaimTask(taskId) {
        (0, assert_1.throwIfNotDefined)(taskId, 'taskId');
        const pathParams = {
            taskId
        };
        return this.put({
            path: '/api/enterprise/tasks/{taskId}/action/unclaim',
            pathParams
        });
    }
}
exports.TaskActionsApi = TaskActionsApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/activiti-rest-api/api/taskActions.api.js.map