"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.TasksApi = void 0;
const model_1 = require("../model");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
class TasksApi extends base_api_1.BaseApi {
    createIdentityLink(taskId, identityLinkRepresentation) {
        (0, assert_1.throwIfNotDefined)(taskId, 'taskId');
        (0, assert_1.throwIfNotDefined)(identityLinkRepresentation, 'identityLinkRepresentation');
        const pathParams = {
            taskId
        };
        return this.post({
            path: '/api/enterprise/tasks/{taskId}/identitylinks',
            pathParams,
            bodyParam: identityLinkRepresentation
        });
    }
    createNewTask(taskRepresentation) {
        (0, assert_1.throwIfNotDefined)(taskRepresentation, 'taskRepresentation');
        return this.post({
            path: '/api/enterprise/tasks',
            bodyParam: taskRepresentation,
            returnType: model_1.TaskRepresentation
        });
    }
    deleteIdentityLink(taskId, family, identityId, type) {
        (0, assert_1.throwIfNotDefined)(taskId, 'taskId');
        (0, assert_1.throwIfNotDefined)(family, 'family');
        (0, assert_1.throwIfNotDefined)(identityId, 'identityId');
        (0, assert_1.throwIfNotDefined)(type, 'type');
        const pathParams = {
            taskId,
            family,
            identityId,
            type
        };
        return this.delete({
            path: '/api/enterprise/tasks/{taskId}/identitylinks/{family}/{identityId}/{type}',
            pathParams
        });
    }
    deleteTask(taskId) {
        (0, assert_1.throwIfNotDefined)(taskId, 'taskId');
        const pathParams = {
            taskId
        };
        return this.delete({
            path: '/api/enterprise/tasks/{taskId}',
            pathParams
        });
    }
    filterTasks(tasksFilter) {
        (0, assert_1.throwIfNotDefined)(tasksFilter, 'tasksFilter');
        return this.post({
            path: '/api/enterprise/tasks/filter',
            bodyParam: tasksFilter,
            returnType: model_1.ResultListDataRepresentationTaskRepresentation
        });
    }
    getIdentityLinkType(taskId, family, identityId, type) {
        (0, assert_1.throwIfNotDefined)(taskId, 'taskId');
        (0, assert_1.throwIfNotDefined)(family, 'family');
        (0, assert_1.throwIfNotDefined)(identityId, 'identityId');
        (0, assert_1.throwIfNotDefined)(type, 'type');
        const pathParams = {
            taskId,
            family,
            identityId,
            type
        };
        return this.get({
            path: '/api/enterprise/tasks/{taskId}/identitylinks/{family}/{identityId}/{type}',
            pathParams
        });
    }
    getIdentityLinksForFamily(taskId, family) {
        (0, assert_1.throwIfNotDefined)(taskId, 'taskId');
        (0, assert_1.throwIfNotDefined)(family, 'family');
        const pathParams = {
            taskId,
            family
        };
        return this.get({
            path: '/api/enterprise/tasks/{taskId}/identitylinks/{family}',
            pathParams
        });
    }
    getIdentityLinks(taskId) {
        (0, assert_1.throwIfNotDefined)(taskId, 'taskId');
        const pathParams = {
            taskId
        };
        return this.get({
            path: '/api/enterprise/tasks/{taskId}/identitylinks',
            pathParams
        });
    }
    getTaskAuditLog(taskId) {
        (0, assert_1.throwIfNotDefined)(taskId, 'taskId');
        const pathParams = {
            taskId
        };
        return this.get({
            path: '/api/enterprise/tasks/{taskId}/audit',
            pathParams
        });
    }
    getTaskAuditPdf(taskId) {
        (0, assert_1.throwIfNotDefined)(taskId, 'taskId');
        const pathParams = {
            taskId
        };
        return this.get({
            path: 'app/rest/tasks/{taskId}/audit',
            pathParams,
            returnType: 'blob'
        });
    }
    getTask(taskId) {
        (0, assert_1.throwIfNotDefined)(taskId, 'taskId');
        const pathParams = {
            taskId
        };
        return this.get({
            path: '/api/enterprise/tasks/{taskId}',
            pathParams,
            returnType: model_1.TaskRepresentation
        });
    }
    listHistoricTasks(queryRequest) {
        (0, assert_1.throwIfNotDefined)(queryRequest, 'queryRequest');
        return this.post({
            path: '/api/enterprise/historic-tasks/query',
            bodyParam: queryRequest,
            returnType: model_1.ResultListDataRepresentationTaskRepresentation
        });
    }
    listTasks(tasksQuery) {
        (0, assert_1.throwIfNotDefined)(tasksQuery, 'tasksQuery');
        return this.post({
            path: '/api/enterprise/tasks/query',
            bodyParam: tasksQuery,
            returnType: model_1.ResultListDataRepresentationTaskRepresentation
        });
    }
    updateTask(taskId, updated) {
        (0, assert_1.throwIfNotDefined)(taskId, 'taskId');
        (0, assert_1.throwIfNotDefined)(updated, 'updated');
        const pathParams = {
            taskId
        };
        return this.put({
            path: '/api/enterprise/tasks/{taskId}',
            pathParams,
            bodyParam: updated,
            returnType: model_1.TaskRepresentation
        });
    }
}
exports.TasksApi = TasksApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/activiti-rest-api/api/tasks.api.js.map