"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserFiltersApi = void 0;
const model_1 = require("../model");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
class UserFiltersApi extends base_api_1.BaseApi {
    createUserProcessInstanceFilter(userProcessInstanceFilterRepresentation) {
        (0, assert_1.throwIfNotDefined)(userProcessInstanceFilterRepresentation, 'userProcessInstanceFilterRepresentation');
        return this.post({
            path: '/api/enterprise/filters/processes',
            bodyParam: userProcessInstanceFilterRepresentation
        });
    }
    createUserTaskFilter(userTaskFilterRepresentation) {
        (0, assert_1.throwIfNotDefined)(userTaskFilterRepresentation, 'userTaskFilterRepresentation');
        return this.post({
            path: '/api/enterprise/filters/tasks',
            bodyParam: userTaskFilterRepresentation,
            returnType: model_1.UserTaskFilterRepresentation
        });
    }
    deleteUserProcessInstanceFilter(userFilterId) {
        (0, assert_1.throwIfNotDefined)(userFilterId, 'userFilterId');
        const pathParams = {
            userFilterId
        };
        return this.delete({
            path: '/api/enterprise/filters/processes/{userFilterId}',
            pathParams
        });
    }
    deleteUserTaskFilter(userFilterId) {
        (0, assert_1.throwIfNotDefined)(userFilterId, 'userFilterId');
        const pathParams = {
            userFilterId
        };
        return this.delete({
            path: '/api/enterprise/filters/tasks/{userFilterId}',
            pathParams
        });
    }
    getUserProcessInstanceFilter(userFilterId) {
        (0, assert_1.throwIfNotDefined)(userFilterId, 'userFilterId');
        const pathParams = {
            userFilterId
        };
        return this.get({
            path: '/api/enterprise/filters/processes/{userFilterId}',
            pathParams
        });
    }
    getUserProcessInstanceFilters(opts) {
        return this.get({
            path: '/api/enterprise/filters/processes',
            queryParams: opts
        });
    }
    getUserTaskFilter(userFilterId) {
        (0, assert_1.throwIfNotDefined)(userFilterId, 'userFilterId');
        const pathParams = {
            userFilterId
        };
        return this.get({
            path: '/api/enterprise/filters/tasks/{userFilterId}',
            pathParams,
            returnType: model_1.UserTaskFilterRepresentation
        });
    }
    getUserTaskFilters(opts) {
        return this.get({
            path: '/api/enterprise/filters/tasks',
            queryParams: opts,
            returnType: model_1.ResultListDataRepresentationUserTaskFilterRepresentation
        });
    }
    orderUserProcessInstanceFilters(filterOrderRepresentation) {
        (0, assert_1.throwIfNotDefined)(filterOrderRepresentation, 'filterOrderRepresentation');
        return this.put({
            path: '/api/enterprise/filters/processes',
            bodyParam: filterOrderRepresentation
        });
    }
    orderUserTaskFilters(filterOrderRepresentation) {
        (0, assert_1.throwIfNotDefined)(filterOrderRepresentation, 'filterOrderRepresentation');
        return this.put({
            path: '/api/enterprise/filters/tasks',
            bodyParam: filterOrderRepresentation
        });
    }
    updateUserProcessInstanceFilter(userFilterId, userProcessInstanceFilterRepresentation) {
        (0, assert_1.throwIfNotDefined)(userFilterId, 'userFilterId');
        (0, assert_1.throwIfNotDefined)(userProcessInstanceFilterRepresentation, 'userProcessInstanceFilterRepresentation');
        const pathParams = {
            userFilterId
        };
        return this.put({
            path: '/api/enterprise/filters/processes/{userFilterId}',
            pathParams,
            bodyParam: userProcessInstanceFilterRepresentation
        });
    }
    updateUserTaskFilter(userFilterId, userTaskFilterRepresentation) {
        (0, assert_1.throwIfNotDefined)(userFilterId, 'userFilterId');
        (0, assert_1.throwIfNotDefined)(userTaskFilterRepresentation, 'userTaskFilterRepresentation');
        const pathParams = {
            userFilterId
        };
        return this.put({
            path: '/api/enterprise/filters/tasks/{userFilterId}',
            pathParams,
            bodyParam: userTaskFilterRepresentation,
            returnType: model_1.UserTaskFilterRepresentation
        });
    }
}
exports.UserFiltersApi = UserFiltersApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/activiti-rest-api/api/userFilters.api.js.map