"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserProfileApi = void 0;
const imageUploadRepresentation_1 = require("../model/imageUploadRepresentation");
const userRepresentation_1 = require("../model/userRepresentation");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
class UserProfileApi extends base_api_1.BaseApi {
    changePassword(changePasswordRepresentation) {
        (0, assert_1.throwIfNotDefined)(changePasswordRepresentation, 'changePasswordRepresentation');
        return this.post({
            path: '/api/enterprise/profile-password',
            bodyParam: changePasswordRepresentation
        });
    }
    getProfilePicture() {
        return this.get({
            path: '/api/enterprise/profile-picture',
            accepts: ['application/json', '*/*']
        });
    }
    getProfilePictureUrl() {
        return this.apiClient.basePath + '/app/rest/admin/profile-picture';
    }
    getProfile() {
        return this.get({
            path: '/api/enterprise/profile',
            returnType: userRepresentation_1.UserRepresentation
        });
    }
    updateProfile(userRepresentation) {
        (0, assert_1.throwIfNotDefined)(userRepresentation, 'userRepresentation');
        return this.post({
            path: '/api/enterprise/profile',
            bodyParam: userRepresentation,
            returnType: userRepresentation_1.UserRepresentation
        });
    }
    uploadProfilePicture(file) {
        (0, assert_1.throwIfNotDefined)(file, 'file');
        const formParams = {
            file
        };
        return this.post({
            path: '/api/enterprise/profile-picture',
            formParams,
            returnType: imageUploadRepresentation_1.ImageUploadRepresentation
        });
    }
}
exports.UserProfileApi = UserProfileApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/activiti-rest-api/api/userProfile.api.js.map