"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ActionsApi = void 0;
const model_1 = require("../model");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
class ActionsApi extends base_api_1.BaseApi {
    actionDetails(actionDefinitionId) {
        (0, assert_1.throwIfNotDefined)(actionDefinitionId, 'actionDefinitionId');
        const pathParams = {
            actionDefinitionId
        };
        return this.get({
            path: '/action-definitions/{actionDefinitionId}',
            pathParams
        });
    }
    actionExec(actionBodyExec) {
        (0, assert_1.throwIfNotDefined)(actionBodyExec, 'actionBodyExec');
        return this.post({
            path: '/action-executions',
            bodyParam: actionBodyExec
        });
    }
    listActions(opts) {
        opts = opts || {};
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            orderBy: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.orderBy, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/action-definitions',
            queryParams,
            returnType: model_1.ActionDefinitionList
        });
    }
    nodeActions(nodeId, opts) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        opts = opts || {};
        const pathParams = {
            nodeId
        };
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            orderBy: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.orderBy, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/nodes/{nodeId}/action-definitions',
            pathParams,
            queryParams,
            returnType: model_1.ActionDefinitionList
        });
    }
}
exports.ActionsApi = ActionsApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/content-rest-api/api/actions.api.js.map