"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuditApi = void 0;
const model_1 = require("../model");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
class AuditApi extends base_api_1.BaseApi {
    deleteAuditEntriesForAuditApp(auditApplicationId, where) {
        (0, assert_1.throwIfNotDefined)(auditApplicationId, 'auditApplicationId');
        (0, assert_1.throwIfNotDefined)(where, 'where');
        const pathParams = {
            auditApplicationId
        };
        const queryParams = {
            where
        };
        return this.delete({
            path: '/audit-applications/{auditApplicationId}/audit-entries',
            pathParams,
            queryParams
        });
    }
    deleteAuditEntry(auditApplicationId, auditEntryId) {
        (0, assert_1.throwIfNotDefined)(auditApplicationId, 'auditApplicationId');
        (0, assert_1.throwIfNotDefined)(auditEntryId, 'auditEntryId');
        const pathParams = {
            auditApplicationId,
            auditEntryId
        };
        return this.delete({
            path: '/audit-applications/{auditApplicationId}/audit-entries/{auditEntryId}',
            pathParams
        });
    }
    getAuditApp(auditApplicationId, opts) {
        (0, assert_1.throwIfNotDefined)(auditApplicationId, 'auditApplicationId');
        const pathParams = {
            auditApplicationId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv'),
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv')
        };
        return this.get({
            path: '/audit-applications/{auditApplicationId}',
            pathParams,
            queryParams
        });
    }
    getAuditEntry(auditApplicationId, auditEntryId, opts) {
        (0, assert_1.throwIfNotDefined)(auditApplicationId, 'auditApplicationId');
        (0, assert_1.throwIfNotDefined)(auditEntryId, 'auditEntryId');
        const pathParams = {
            auditApplicationId,
            auditEntryId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/audit-applications/{auditApplicationId}/audit-entries/{auditEntryId}',
            pathParams,
            queryParams,
            returnType: model_1.AuditEntryEntry
        });
    }
    listAuditApps(opts) {
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/audit-applications',
            queryParams,
            returnType: model_1.AuditAppPaging
        });
    }
    listAuditEntriesForAuditApp(auditApplicationId, opts) {
        (0, assert_1.throwIfNotDefined)(auditApplicationId, 'auditApplicationId');
        opts = opts || {};
        const pathParams = {
            auditApplicationId
        };
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            orderBy: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.orderBy, 'csv'),
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            where: opts === null || opts === void 0 ? void 0 : opts.where,
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/audit-applications/{auditApplicationId}/audit-entries',
            pathParams,
            queryParams,
            returnType: model_1.AuditEntryPaging
        });
    }
    listAuditEntriesForNode(nodeId, opts) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        opts = opts || {};
        const pathParams = {
            nodeId
        };
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            orderBy: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.orderBy, 'csv'),
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            where: opts === null || opts === void 0 ? void 0 : opts.where,
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/nodes/{nodeId}/audit-entries',
            pathParams,
            queryParams,
            returnType: model_1.AuditEntryPaging
        });
    }
    updateAuditApp(auditApplicationId, auditAppBodyUpdate, opts) {
        (0, assert_1.throwIfNotDefined)(auditApplicationId, 'auditApplicationId');
        (0, assert_1.throwIfNotDefined)(auditAppBodyUpdate, 'auditAppBodyUpdate');
        const pathParams = {
            auditApplicationId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.put({
            path: '/audit-applications/{auditApplicationId}',
            pathParams,
            queryParams,
            bodyParam: auditAppBodyUpdate
        });
    }
}
exports.AuditApi = AuditApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/content-rest-api/api/audit.api.js.map