"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.CategoriesApi = void 0;
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
const model_1 = require("../model");
class CategoriesApi extends base_api_1.BaseApi {
    getSubcategories(categoryId, opts) {
        (0, assert_1.throwIfNotDefined)(categoryId, 'categoryId');
        const pathParams = {
            categoryId
        };
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv'),
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv')
        };
        return this.get({
            path: '/categories/{categoryId}/subcategories',
            pathParams,
            queryParams,
            returnType: model_1.CategoryPaging
        });
    }
    getCategory(categoryId, opts) {
        (0, assert_1.throwIfNotDefined)(categoryId, 'categoryId');
        const pathParams = {
            categoryId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv'),
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv')
        };
        return this.get({
            path: '/categories/{categoryId}',
            pathParams,
            queryParams,
            returnType: model_1.CategoryEntry
        });
    }
    getCategoryLinksForNode(nodeId, opts) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        const pathParams = {
            nodeId
        };
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv'),
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv')
        };
        return this.get({
            path: '/nodes/{nodeId}/category-links',
            pathParams,
            queryParams,
            returnType: model_1.CategoryPaging
        });
    }
    deleteCategory(categoryId) {
        (0, assert_1.throwIfNotDefined)(categoryId, 'categoryId');
        const pathParams = {
            categoryId
        };
        return this.delete({
            path: '/categories/{categoryId}',
            pathParams
        });
    }
    unlinkNodeFromCategory(nodeId, categoryId) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        (0, assert_1.throwIfNotDefined)(categoryId, 'categoryId');
        const pathParams = {
            nodeId,
            categoryId
        };
        return this.delete({
            path: '/nodes/{nodeId}/category-links/{categoryId}',
            pathParams
        });
    }
    updateCategory(categoryId, categoryBodyUpdate, opts) {
        (0, assert_1.throwIfNotDefined)(categoryId, 'categoryId');
        (0, assert_1.throwIfNotDefined)(categoryBodyUpdate, 'categoryBodyUpdate');
        const pathParams = {
            categoryId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv'),
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv')
        };
        return this.put({
            path: '/categories/{categoryId}',
            pathParams,
            queryParams,
            bodyParam: categoryBodyUpdate,
            returnType: model_1.CategoryEntry
        });
    }
    createSubcategories(categoryId, categoryBodyCreate, opts) {
        (0, assert_1.throwIfNotDefined)(categoryId, 'categoryId');
        (0, assert_1.throwIfNotDefined)(categoryBodyCreate, 'categoryBodyCreate');
        const pathParams = {
            categoryId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv'),
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv')
        };
        return this.post({
            path: '/categories/{categoryId}/subcategories',
            pathParams,
            queryParams,
            bodyParam: categoryBodyCreate,
            returnType: model_1.CategoryEntry
        });
    }
    linkNodeToCategory(nodeId, categoryLinkBodyCreate, opts) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        (0, assert_1.throwIfNotDefined)(categoryLinkBodyCreate, 'categoryLinkBodyCreate');
        const pathParams = {
            nodeId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv'),
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv')
        };
        return this.post({
            path: '/nodes/{nodeId}/category-links',
            pathParams,
            queryParams,
            bodyParam: categoryLinkBodyCreate,
            returnType: model_1.CategoryEntry
        });
    }
}
exports.CategoriesApi = CategoriesApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/content-rest-api/api/categories.api.js.map