"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.FavoritesApi = void 0;
const model_1 = require("../model");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
class FavoritesApi extends base_api_1.BaseApi {
    createFavorite(personId, favoriteBodyCreate, opts) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        (0, assert_1.throwIfNotDefined)(favoriteBodyCreate, 'favoriteBodyCreate');
        const pathParams = {
            personId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.post({
            path: '/people/{personId}/favorites',
            pathParams,
            queryParams,
            bodyParam: favoriteBodyCreate,
            returnType: model_1.FavoriteEntry
        });
    }
    createSiteFavorite(personId, favoriteSiteBodyCreate, opts) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        (0, assert_1.throwIfNotDefined)(favoriteSiteBodyCreate, 'favoriteSiteBodyCreate');
        const pathParams = {
            personId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.post({
            path: '/people/{personId}/favorite-sites',
            pathParams,
            queryParams,
            bodyParam: favoriteSiteBodyCreate
        });
    }
    deleteFavorite(personId, favoriteId) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        (0, assert_1.throwIfNotDefined)(favoriteId, 'favoriteId');
        const pathParams = {
            personId,
            favoriteId
        };
        return this.delete({
            path: '/people/{personId}/favorites/{favoriteId}',
            pathParams
        });
    }
    deleteSiteFavorite(personId, siteId) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        const pathParams = {
            personId,
            siteId
        };
        return this.delete({
            path: '/people/{personId}/favorite-sites/{siteId}',
            pathParams
        });
    }
    getFavorite(personId, favoriteId, opts) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        (0, assert_1.throwIfNotDefined)(favoriteId, 'favoriteId');
        const pathParams = {
            personId,
            favoriteId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/people/{personId}/favorites/{favoriteId}',
            pathParams,
            queryParams,
            returnType: model_1.FavoriteEntry
        });
    }
    getFavoriteSite(personId, siteId, opts) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        const pathParams = {
            personId,
            siteId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/people/{personId}/favorite-sites/{siteId}',
            pathParams,
            queryParams,
            returnType: model_1.SiteEntry
        });
    }
    listFavoriteSitesForPerson(personId, opts) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        const pathParams = {
            personId
        };
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/people/{personId}/favorite-sites',
            pathParams,
            queryParams,
            returnType: model_1.SitePaging
        });
    }
    listFavorites(personId, opts) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        opts = opts || {};
        const pathParams = {
            personId
        };
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            orderBy: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.orderBy, 'csv'),
            where: opts === null || opts === void 0 ? void 0 : opts.where,
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/people/{personId}/favorites',
            pathParams,
            queryParams,
            returnType: model_1.FavoritePaging
        });
    }
}
exports.FavoritesApi = FavoritesApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/content-rest-api/api/favorites.api.js.map