"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.GroupsApi = void 0;
const model_1 = require("../model");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
class GroupsApi extends base_api_1.BaseApi {
    createGroup(groupBodyCreate, opts) {
        (0, assert_1.throwIfNotDefined)(groupBodyCreate, 'groupBodyCreate');
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.post({
            path: '/groups',
            queryParams,
            bodyParam: groupBodyCreate
        });
    }
    createGroupMembership(groupId, groupMembershipBodyCreate, opts) {
        (0, assert_1.throwIfNotDefined)(groupId, 'groupId');
        (0, assert_1.throwIfNotDefined)(groupMembershipBodyCreate, 'groupMembershipBodyCreate');
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.post({
            path: '/groups/{groupId}/members',
            pathParams: { groupId },
            queryParams,
            bodyParam: groupMembershipBodyCreate
        });
    }
    deleteGroup(groupId, opts) {
        (0, assert_1.throwIfNotDefined)(groupId, 'groupId');
        opts = opts || {};
        const cascadeDelete = opts['cascade'] ? opts['cascade'] : false;
        const pathParams = {
            groupId
        };
        const queryParams = {
            cascade: cascadeDelete
        };
        return this.delete({
            path: '/groups/{groupId}',
            pathParams,
            queryParams
        });
    }
    deleteGroupMembership(groupId, groupMemberId) {
        (0, assert_1.throwIfNotDefined)(groupId, 'groupId');
        (0, assert_1.throwIfNotDefined)(groupMemberId, 'groupMemberId');
        const pathParams = {
            groupId,
            groupMemberId
        };
        return this.delete({
            path: '/groups/{groupId}/members/{groupMemberId}',
            pathParams
        });
    }
    getGroup(groupId, opts) {
        (0, assert_1.throwIfNotDefined)(groupId, 'groupId');
        const pathParams = {
            groupId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/groups/{groupId}',
            pathParams,
            queryParams
        });
    }
    listGroupMemberships(groupId, opts) {
        (0, assert_1.throwIfNotDefined)(groupId, 'groupId');
        const pathParams = {
            groupId
        };
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            orderBy: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.orderBy, 'csv'),
            where: opts === null || opts === void 0 ? void 0 : opts.where,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/groups/{groupId}/members',
            pathParams,
            queryParams,
            returnType: model_1.GroupMemberPaging
        });
    }
    listGroupMembershipsForPerson(personId, opts) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        const pathParams = {
            personId
        };
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            orderBy: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.orderBy, 'csv'),
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            where: opts === null || opts === void 0 ? void 0 : opts.where,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/people/{personId}/groups',
            pathParams,
            queryParams,
            returnType: model_1.GroupPaging
        });
    }
    listGroups(opts) {
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            orderBy: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.orderBy, 'csv'),
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            where: opts === null || opts === void 0 ? void 0 : opts.where,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/groups',
            queryParams,
            returnType: model_1.GroupPaging
        });
    }
    updateGroup(groupId, groupBodyUpdate, opts) {
        (0, assert_1.throwIfNotDefined)(groupId, 'groupId');
        (0, assert_1.throwIfNotDefined)(groupBodyUpdate, 'groupBodyUpdate');
        const pathParams = {
            groupId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.put({
            path: '/groups/{groupId}',
            pathParams,
            queryParams,
            bodyParam: groupBodyUpdate
        });
    }
}
exports.GroupsApi = GroupsApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/content-rest-api/api/groups.api.js.map