"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.NetworksApi = void 0;
const personNetworkEntry_1 = require("../model/personNetworkEntry");
const personNetworkPaging_1 = require("../model/personNetworkPaging");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
class NetworksApi extends base_api_1.BaseApi {
    getNetwork(networkId, opts) {
        (0, assert_1.throwIfNotDefined)(networkId, 'networkId');
        const pathParams = {
            networkId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/networks/{networkId}',
            pathParams,
            queryParams,
            returnType: personNetworkEntry_1.PersonNetworkEntry
        });
    }
    getNetworkForPerson(personId, networkId, opts) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        (0, assert_1.throwIfNotDefined)(networkId, 'networkId');
        const pathParams = {
            personId,
            networkId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/people/{personId}/networks/{networkId}',
            pathParams,
            queryParams,
            returnType: personNetworkEntry_1.PersonNetworkEntry
        });
    }
    listNetworksForPerson(personId, opts) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        const pathParams = {
            personId
        };
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/people/{personId}/networks',
            pathParams,
            queryParams,
            returnType: personNetworkPaging_1.PersonNetworkPaging
        });
    }
}
exports.NetworksApi = NetworksApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/content-rest-api/api/networks.api.js.map