"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.PreferencesApi = void 0;
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
class PreferencesApi extends base_api_1.BaseApi {
    getPreference(personId, preferenceName, opts) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        (0, assert_1.throwIfNotDefined)(preferenceName, 'preferenceName');
        const pathParams = {
            personId,
            preferenceName
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/people/{personId}/preferences/{preferenceName}',
            pathParams,
            queryParams
        });
    }
    listPreferences(personId, opts) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        const pathParams = {
            personId
        };
        const queryParams = Object.assign(Object.assign({}, (opts || {})), { fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv') });
        return this.get({
            path: '/people/{personId}/preferences',
            pathParams,
            queryParams
        });
    }
    updatePreference(personId, preferenceName, preferenceValue) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        (0, assert_1.throwIfNotDefined)(preferenceName, 'preferenceName');
        (0, assert_1.throwIfNotDefined)(preferenceValue, 'preferenceValue');
        const pathParams = {
            personId,
            preferenceName
        };
        const bodyParam = {
            value: preferenceValue
        };
        return this.put({
            path: '/people/{personId}/preferences/{preferenceName}',
            pathParams,
            bodyParam: bodyParam
        });
    }
}
exports.PreferencesApi = PreferencesApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/content-rest-api/api/preferences.api.js.map