"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.QueriesApi = void 0;
const nodePaging_1 = require("../model/nodePaging");
const personPaging_1 = require("../model/personPaging");
const sitePaging_1 = require("../model/sitePaging");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
class QueriesApi extends base_api_1.BaseApi {
    findNodes(term, opts) {
        (0, assert_1.throwIfNotDefined)(term, 'term');
        const queryParams = {
            term,
            rootNodeId: opts === null || opts === void 0 ? void 0 : opts.rootNodeId,
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            nodeType: opts === null || opts === void 0 ? void 0 : opts.nodeType,
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            orderBy: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.orderBy, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/queries/nodes',
            queryParams,
            returnType: nodePaging_1.NodePaging
        });
    }
    findPeople(term, opts) {
        (0, assert_1.throwIfNotDefined)(term, 'term');
        opts = opts || {};
        const queryParams = {
            term,
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv'),
            orderBy: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.orderBy, 'csv')
        };
        return this.get({
            path: '/queries/people',
            queryParams,
            returnType: personPaging_1.PersonPaging
        });
    }
    findSites(term, opts) {
        (0, assert_1.throwIfNotDefined)(term, 'term');
        const queryParams = {
            term,
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            orderBy: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.orderBy, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/queries/sites',
            queryParams,
            returnType: sitePaging_1.SitePaging
        });
    }
}
exports.QueriesApi = QueriesApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/content-rest-api/api/queries.api.js.map