"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.RatingsApi = void 0;
const ratingEntry_1 = require("../model/ratingEntry");
const ratingPaging_1 = require("../model/ratingPaging");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
class RatingsApi extends base_api_1.BaseApi {
    createRating(nodeId, ratingBodyCreate, opts) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        (0, assert_1.throwIfNotDefined)(ratingBodyCreate, 'ratingBodyCreate');
        const pathParams = {
            nodeId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.post({
            path: '/nodes/{nodeId}/ratings',
            pathParams,
            queryParams,
            bodyParam: ratingBodyCreate,
            returnType: ratingEntry_1.RatingEntry
        });
    }
    deleteRating(nodeId, ratingId) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        (0, assert_1.throwIfNotDefined)(ratingId, 'ratingId');
        const pathParams = {
            nodeId,
            ratingId
        };
        return this.delete({
            path: '/nodes/{nodeId}/ratings/{ratingId}',
            pathParams
        });
    }
    getRating(nodeId, ratingId, opts) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        (0, assert_1.throwIfNotDefined)(ratingId, 'ratingId');
        const pathParams = {
            nodeId,
            ratingId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/nodes/{nodeId}/ratings/{ratingId}',
            pathParams,
            queryParams,
            returnType: ratingEntry_1.RatingEntry
        });
    }
    listRatings(nodeId, opts) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        const pathParams = {
            nodeId
        };
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/nodes/{nodeId}/ratings',
            pathParams,
            queryParams,
            returnType: ratingPaging_1.RatingPaging
        });
    }
}
exports.RatingsApi = RatingsApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/content-rest-api/api/ratings.api.js.map