"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.RenditionsApi = void 0;
const model_1 = require("../model");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
class RenditionsApi extends base_api_1.BaseApi {
    createRendition(nodeId, renditionBodyCreate) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        (0, assert_1.throwIfNotDefined)(renditionBodyCreate, 'renditionBodyCreate');
        const pathParams = {
            nodeId
        };
        return this.post({
            path: '/nodes/{nodeId}/renditions',
            pathParams,
            bodyParam: renditionBodyCreate
        });
    }
    getRendition(nodeId, renditionId) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        (0, assert_1.throwIfNotDefined)(renditionId, 'renditionId');
        const pathParams = {
            nodeId,
            renditionId
        };
        return this.get({
            path: '/nodes/{nodeId}/renditions/{renditionId}',
            pathParams,
            returnType: model_1.RenditionEntry
        });
    }
    getRenditionContent(nodeId, renditionId, opts) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        (0, assert_1.throwIfNotDefined)(renditionId, 'renditionId');
        const pathParams = {
            nodeId,
            renditionId
        };
        const queryParams = {
            attachment: opts === null || opts === void 0 ? void 0 : opts.attachment,
            placeholder: opts === null || opts === void 0 ? void 0 : opts.placeholder
        };
        const headerParams = {
            'If-Modified-Since': opts === null || opts === void 0 ? void 0 : opts.ifModifiedSince,
            Range: opts === null || opts === void 0 ? void 0 : opts.range
        };
        const accepts = ['application/octet-stream'];
        return this.get({
            path: '/nodes/{nodeId}/renditions/{renditionId}/content',
            pathParams,
            queryParams,
            headerParams,
            accepts,
            returnType: 'blob'
        });
    }
    listRenditions(nodeId, opts) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        const pathParams = {
            nodeId
        };
        return this.get({
            path: '/nodes/{nodeId}/renditions',
            pathParams,
            queryParams: opts,
            returnType: model_1.RenditionPaging
        });
    }
    requestDirectAccessUrl(nodeId, renditionId) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        (0, assert_1.throwIfNotDefined)(renditionId, 'renditionId');
        const pathParams = {
            nodeId,
            renditionId
        };
        return this.post({
            path: '/nodes/{nodeId}/renditions/{renditionId}/request-direct-access-url',
            pathParams,
            returnType: model_1.DirectAccessUrlEntry
        });
    }
}
exports.RenditionsApi = RenditionsApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/content-rest-api/api/renditions.api.js.map