"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.SharedlinksApi = void 0;
const renditionEntry_1 = require("../model/renditionEntry");
const renditionPaging_1 = require("../model/renditionPaging");
const sharedLinkEntry_1 = require("../model/sharedLinkEntry");
const sharedLinkPaging_1 = require("../model/sharedLinkPaging");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
class SharedlinksApi extends base_api_1.BaseApi {
    createSharedLink(sharedLinkBodyCreate, opts) {
        (0, assert_1.throwIfNotDefined)(sharedLinkBodyCreate, 'sharedLinkBodyCreate');
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.post({
            path: '/shared-links',
            queryParams,
            bodyParam: sharedLinkBodyCreate,
            returnType: sharedLinkEntry_1.SharedLinkEntry
        });
    }
    deleteSharedLink(sharedId) {
        (0, assert_1.throwIfNotDefined)(sharedId, 'sharedId');
        const pathParams = {
            sharedId
        };
        return this.delete({
            path: '/shared-links/{sharedId}',
            pathParams
        });
    }
    emailSharedLink(sharedId, sharedLinkBodyEmail) {
        (0, assert_1.throwIfNotDefined)(sharedId, 'sharedId');
        (0, assert_1.throwIfNotDefined)(sharedLinkBodyEmail, 'sharedLinkBodyEmail');
        const pathParams = {
            sharedId
        };
        return this.post({
            path: '/shared-links/{sharedId}/email',
            pathParams,
            bodyParam: sharedLinkBodyEmail
        });
    }
    getSharedLink(sharedId, opts) {
        (0, assert_1.throwIfNotDefined)(sharedId, 'sharedId');
        const pathParams = {
            sharedId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/shared-links/{sharedId}',
            pathParams,
            queryParams,
            returnType: sharedLinkEntry_1.SharedLinkEntry
        });
    }
    getSharedLinkContent(sharedId, opts) {
        (0, assert_1.throwIfNotDefined)(sharedId, 'sharedId');
        const pathParams = {
            sharedId
        };
        const queryParams = {
            attachment: opts === null || opts === void 0 ? void 0 : opts.attachment
        };
        const headerParams = {
            'If-Modified-Since': opts === null || opts === void 0 ? void 0 : opts.ifModifiedSince,
            Range: opts === null || opts === void 0 ? void 0 : opts.range
        };
        return this.get({
            path: '/shared-links/{sharedId}/content',
            pathParams,
            queryParams,
            headerParams,
            accepts: ['application/octet-stream'],
            returnType: 'blob'
        });
    }
    getSharedLinkRendition(sharedId, renditionId) {
        (0, assert_1.throwIfNotDefined)(sharedId, 'sharedId');
        (0, assert_1.throwIfNotDefined)(renditionId, 'renditionId');
        const pathParams = {
            sharedId,
            renditionId
        };
        return this.get({
            path: '/shared-links/{sharedId}/renditions/{renditionId}',
            pathParams,
            returnType: renditionEntry_1.RenditionEntry
        });
    }
    getSharedLinkRenditionContent(sharedId, renditionId, opts) {
        (0, assert_1.throwIfNotDefined)(sharedId, 'sharedId');
        (0, assert_1.throwIfNotDefined)(renditionId, 'renditionId');
        const pathParams = {
            sharedId,
            renditionId
        };
        const queryParams = {
            attachment: opts === null || opts === void 0 ? void 0 : opts.attachment
        };
        const headerParams = {
            'If-Modified-Since': opts === null || opts === void 0 ? void 0 : opts.ifModifiedSince,
            Range: opts === null || opts === void 0 ? void 0 : opts.range
        };
        return this.get({
            path: '/shared-links/{sharedId}/renditions/{renditionId}/content',
            pathParams,
            queryParams,
            headerParams,
            accepts: ['application/octet-stream'],
            returnType: 'blob'
        });
    }
    listSharedLinkRenditions(sharedId) {
        (0, assert_1.throwIfNotDefined)(sharedId, 'sharedId');
        const pathParams = {
            sharedId
        };
        return this.get({
            path: '/shared-links/{sharedId}/renditions',
            pathParams,
            returnType: renditionPaging_1.RenditionPaging
        });
    }
    listSharedLinks(opts) {
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            where: opts === null || opts === void 0 ? void 0 : opts.where,
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/shared-links',
            queryParams,
            returnType: sharedLinkPaging_1.SharedLinkPaging
        });
    }
}
exports.SharedlinksApi = SharedlinksApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/content-rest-api/api/sharedlinks.api.js.map