"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.SitesApi = void 0;
const model_1 = require("../model");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
class SitesApi extends base_api_1.BaseApi {
    approveSiteMembershipRequest(siteId, inviteeId, opts) {
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        (0, assert_1.throwIfNotDefined)(inviteeId, 'inviteeId');
        const postBody = opts === null || opts === void 0 ? void 0 : opts.siteMembershipApprovalBody;
        const pathParams = {
            siteId,
            inviteeId
        };
        return this.post({
            path: '/sites/{siteId}/site-membership-requests/{inviteeId}/approve',
            pathParams,
            bodyParam: postBody
        });
    }
    createSite(siteBodyCreate, opts) {
        (0, assert_1.throwIfNotDefined)(siteBodyCreate, 'siteBodyCreate');
        opts = opts || {};
        const queryParams = {
            skipConfiguration: opts === null || opts === void 0 ? void 0 : opts.skipConfiguration,
            skipAddToFavorites: opts === null || opts === void 0 ? void 0 : opts.skipAddToFavorites,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.post({
            path: '/sites',
            queryParams,
            bodyParam: siteBodyCreate,
            returnType: model_1.SiteEntry
        });
    }
    createSiteMembership(siteId, siteMembershipBodyCreate, opts) {
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        (0, assert_1.throwIfNotDefined)(siteMembershipBodyCreate, 'siteMembershipBodyCreate');
        const pathParams = {
            siteId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.post({
            path: '/sites/{siteId}/members',
            pathParams,
            queryParams,
            bodyParam: siteMembershipBodyCreate,
            returnType: model_1.SiteMemberEntry
        });
    }
    createSiteMembershipRequestForPerson(personId, siteMembershipRequestBodyCreate, opts) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        (0, assert_1.throwIfNotDefined)(siteMembershipRequestBodyCreate, 'siteMembershipRequestBodyCreate');
        const pathParams = {
            personId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.post({
            path: '/people/{personId}/site-membership-requests',
            pathParams,
            queryParams,
            bodyParam: siteMembershipRequestBodyCreate,
            returnType: model_1.SiteMembershipRequestEntry
        });
    }
    deleteSite(siteId, opts) {
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        const pathParams = {
            siteId
        };
        const queryParams = {
            permanent: opts === null || opts === void 0 ? void 0 : opts.permanent
        };
        return this.delete({
            path: '/sites/{siteId}',
            pathParams,
            queryParams
        });
    }
    deleteSiteMembership(siteId, personId) {
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        const pathParams = {
            siteId,
            personId
        };
        return this.delete({
            path: '/sites/{siteId}/members/{personId}',
            pathParams
        });
    }
    deleteSiteMembershipForPerson(personId, siteId) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        const pathParams = {
            personId,
            siteId
        };
        return this.delete({
            path: '/people/{personId}/sites/{siteId}',
            pathParams
        });
    }
    deleteSiteMembershipRequestForPerson(personId, siteId) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        const pathParams = {
            personId,
            siteId
        };
        return this.delete({
            path: '/people/{personId}/site-membership-requests/{siteId}',
            pathParams
        });
    }
    getSite(siteId, opts) {
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        const pathParams = {
            siteId
        };
        const queryParams = {
            relations: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.relations, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/sites/{siteId}',
            pathParams,
            queryParams,
            returnType: model_1.SiteEntry
        });
    }
    getSiteContainer(siteId, containerId, opts) {
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        (0, assert_1.throwIfNotDefined)(containerId, 'containerId');
        const pathParams = {
            siteId,
            containerId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/sites/{siteId}/containers/{containerId}',
            pathParams,
            queryParams
        });
    }
    getSiteMembership(siteId, personId, opts) {
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        const pathParams = {
            siteId,
            personId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/sites/{siteId}/members/{personId}',
            pathParams,
            queryParams,
            returnType: model_1.SiteMemberEntry
        });
    }
    getSiteMembershipForPerson(personId, siteId) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        const pathParams = {
            personId,
            siteId
        };
        return this.get({
            path: '/people/{personId}/sites/{siteId}',
            pathParams,
            returnType: model_1.SiteRoleEntry
        });
    }
    getSiteMembershipRequestForPerson(personId, siteId, opts) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        const pathParams = {
            personId,
            siteId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/people/{personId}/site-membership-requests/{siteId}',
            pathParams,
            queryParams,
            returnType: model_1.SiteMembershipRequestEntry
        });
    }
    getSiteMembershipRequests(opts) {
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            where: opts === null || opts === void 0 ? void 0 : opts.where,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/site-membership-requests',
            queryParams,
            returnType: model_1.SiteMembershipRequestWithPersonPaging
        });
    }
    listSiteContainers(siteId, opts) {
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        const pathParams = {
            siteId
        };
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/sites/{siteId}/containers',
            pathParams,
            queryParams,
            returnType: model_1.SiteContainerPaging
        });
    }
    listSiteMembershipRequestsForPerson(personId, opts) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        const pathParams = {
            personId
        };
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/people/{personId}/site-membership-requests',
            pathParams,
            queryParams,
            returnType: model_1.SiteMembershipRequestPaging
        });
    }
    listSiteMemberships(siteId, opts) {
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        opts = opts || {};
        const pathParams = {
            siteId
        };
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            where: opts === null || opts === void 0 ? void 0 : opts.where,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/sites/{siteId}/members',
            pathParams,
            queryParams,
            returnType: model_1.SiteMemberPaging
        });
    }
    listSiteMembershipsForPerson(personId, opts) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        opts = opts || {};
        const pathParams = {
            personId
        };
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            orderBy: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.orderBy, 'csv'),
            relations: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.relations, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv'),
            where: opts === null || opts === void 0 ? void 0 : opts.where
        };
        return this.get({
            path: '/people/{personId}/sites',
            pathParams,
            queryParams,
            returnType: model_1.SiteRolePaging
        });
    }
    listSites(opts) {
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            orderBy: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.orderBy, 'csv'),
            relations: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.relations, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv'),
            where: opts === null || opts === void 0 ? void 0 : opts.where
        };
        return this.get({
            path: '/sites',
            queryParams,
            returnType: model_1.SitePaging
        });
    }
    rejectSiteMembershipRequest(siteId, inviteeId, opts) {
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        (0, assert_1.throwIfNotDefined)(inviteeId, 'inviteeId');
        const postBody = opts === null || opts === void 0 ? void 0 : opts.siteMembershipRejectionBody;
        const pathParams = {
            siteId,
            inviteeId
        };
        return this.post({
            path: '/sites/{siteId}/site-membership-requests/{inviteeId}/reject',
            pathParams,
            bodyParam: postBody
        });
    }
    updateSite(siteId, siteBodyUpdate, opts) {
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        (0, assert_1.throwIfNotDefined)(siteBodyUpdate, 'siteBodyUpdate');
        opts = opts || {};
        const pathParams = {
            siteId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.put({
            path: '/sites/{siteId}',
            pathParams,
            queryParams,
            bodyParam: siteBodyUpdate,
            returnType: model_1.SiteEntry
        });
    }
    updateSiteMembership(siteId, personId, siteMembershipBodyUpdate, opts) {
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        (0, assert_1.throwIfNotDefined)(siteMembershipBodyUpdate, 'siteMembershipBodyUpdate');
        const pathParams = {
            siteId,
            personId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.put({
            path: '/sites/{siteId}/members/{personId}',
            pathParams,
            queryParams,
            bodyParam: siteMembershipBodyUpdate,
            returnType: model_1.SiteMemberEntry
        });
    }
    updateSiteMembershipRequestForPerson(personId, siteId, siteMembershipRequestBodyUpdate, opts) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        (0, assert_1.throwIfNotDefined)(siteMembershipRequestBodyUpdate, 'siteMembershipRequestBodyUpdate');
        const pathParams = {
            personId,
            siteId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.put({
            path: '/people/{personId}/site-membership-requests/{siteId}',
            pathParams,
            queryParams,
            bodyParam: siteMembershipRequestBodyUpdate,
            returnType: model_1.SiteMembershipRequestEntry
        });
    }
    createSiteGroupMembership(siteId, siteMembershipBodyCreate, opts) {
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        (0, assert_1.throwIfNotDefined)(siteMembershipBodyCreate, 'siteMembershipBodyCreate');
        const pathParams = {
            siteId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.post({
            path: '/sites/{siteId}/group-members',
            pathParams,
            queryParams,
            bodyParam: siteMembershipBodyCreate,
            returnType: model_1.SiteGroupEntry
        });
    }
    listSiteGroups(siteId, opts) {
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        const pathParams = {
            siteId
        };
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/sites/{siteId}/group-members',
            pathParams,
            queryParams,
            returnType: model_1.SiteGroupPaging
        });
    }
    getSiteGroupMembership(siteId, groupId, opts) {
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        (0, assert_1.throwIfNotDefined)(groupId, 'groupId');
        const pathParams = {
            siteId,
            groupId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/sites/{siteId}/group-members/{groupId}',
            pathParams,
            queryParams,
            returnType: model_1.SiteGroupEntry
        });
    }
    updateSiteGroupMembership(siteId, groupId, siteMembershipBodyUpdate, opts) {
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        (0, assert_1.throwIfNotDefined)(groupId, 'groupId');
        (0, assert_1.throwIfNotDefined)(siteMembershipBodyUpdate, 'siteMembershipBodyUpdate');
        const pathParams = {
            siteId,
            groupId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.put({
            path: '/sites/{siteId}/group-members/{groupId}',
            pathParams,
            queryParams,
            bodyParam: siteMembershipBodyUpdate,
            returnType: model_1.SiteGroupEntry
        });
    }
    deleteSiteGroupMembership(siteId, groupId) {
        (0, assert_1.throwIfNotDefined)(siteId, 'siteId');
        (0, assert_1.throwIfNotDefined)(groupId, 'groupId');
        const pathParams = {
            siteId,
            groupId
        };
        return this.delete({
            path: '/sites/{siteId}/group-members/{groupId}',
            pathParams
        });
    }
}
exports.SitesApi = SitesApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/content-rest-api/api/sites.api.js.map