"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ClassificationGuidesApi = void 0;
const model_1 = require("../model");
const base_api_1 = require("./base.api");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
const assert_1 = require("../../../assert");
class ClassificationGuidesApi extends base_api_1.BaseApi {
    combinedInstructions(opts) {
        return this.post({
            path: '/combined-instructions',
            bodyParam: opts === null || opts === void 0 ? void 0 : opts.instructions
        });
    }
    createClassificationGuide(classificationGuide) {
        (0, assert_1.throwIfNotDefined)(classificationGuide, 'classificationGuide');
        return this.post({
            path: '/classification-guides',
            bodyParam: classificationGuide
        });
    }
    createSubtopic(topicId, topic, opts) {
        (0, assert_1.throwIfNotDefined)(topicId, 'topicId');
        (0, assert_1.throwIfNotDefined)(topic, 'topic');
        const pathParams = {
            topicId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv')
        };
        return this.post({
            path: '/topics/{topicId}/subtopics',
            pathParams,
            queryParams,
            bodyParam: topic,
            returnType: model_1.TopicEntry
        });
    }
    createTopic(classificationGuideId, topic, opts) {
        (0, assert_1.throwIfNotDefined)(classificationGuideId, 'classificationGuideId');
        (0, assert_1.throwIfNotDefined)(topic, 'topic');
        const pathParams = {
            classificationGuideId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv')
        };
        return this.post({
            path: '/classification-guides/{classificationGuideId}/topics',
            pathParams,
            queryParams,
            bodyParam: topic,
            returnType: model_1.TopicEntry
        });
    }
    deleteClassificationGuide(classificationGuideId) {
        (0, assert_1.throwIfNotDefined)(classificationGuideId, 'classificationGuideId');
        const pathParams = {
            classificationGuideId
        };
        return this.delete({
            path: '/classification-guides/{classificationGuideId}',
            pathParams
        });
    }
    deleteTopic(topicId) {
        (0, assert_1.throwIfNotDefined)(topicId, 'topicId');
        const pathParams = {
            topicId
        };
        return this.delete({
            path: '/topics/{topicId}',
            pathParams
        });
    }
    listClassificationGuides(opts) {
        opts = opts || {};
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            orderBy: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.orderBy, 'csv'),
            where: opts === null || opts === void 0 ? void 0 : opts.where
        };
        return this.get({
            path: '/classification-guides',
            queryParams
        });
    }
    listSubtopics(topicId, opts) {
        (0, assert_1.throwIfNotDefined)(topicId, 'topicId');
        opts = opts || {};
        const pathParams = {
            topicId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            orderBy: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.orderBy, 'csv'),
            where: opts === null || opts === void 0 ? void 0 : opts.where,
            includeSource: opts === null || opts === void 0 ? void 0 : opts.includeSource
        };
        return this.get({
            path: '/topics/{topicId}/subtopics',
            pathParams,
            queryParams,
            returnType: model_1.SubtopicPaging
        });
    }
    listTopics(classificationGuideId, opts) {
        (0, assert_1.throwIfNotDefined)(classificationGuideId, 'classificationGuideId');
        opts = opts || {};
        const pathParams = {
            classificationGuideId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            orderBy: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.orderBy, 'csv'),
            where: opts === null || opts === void 0 ? void 0 : opts.where,
            includeSource: opts === null || opts === void 0 ? void 0 : opts.includeSource
        };
        return this.get({
            path: '/classification-guides/{classificationGuideId}/topics',
            pathParams,
            queryParams,
            returnType: model_1.TopicPaging
        });
    }
    showClassificationGuideById(classificationGuideId) {
        (0, assert_1.throwIfNotDefined)(classificationGuideId, 'classificationGuideId');
        const pathParams = {
            classificationGuideId
        };
        return this.get({
            path: '/classification-guides/{classificationGuideId}',
            pathParams
        });
    }
    showTopicById(topicId, opts) {
        (0, assert_1.throwIfNotDefined)(topicId, 'topicId');
        const pathParams = {
            topicId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv')
        };
        return this.post({
            path: '/topics/{topicId}',
            pathParams,
            queryParams,
            returnType: model_1.TopicEntry
        });
    }
    updateClassificationGuide(classificationGuideId, classificationGuide) {
        (0, assert_1.throwIfNotDefined)(classificationGuideId, 'classificationGuideId');
        (0, assert_1.throwIfNotDefined)(classificationGuide, 'classificationGuide');
        const pathParams = {
            classificationGuideId
        };
        return this.put({
            path: '/classification-guides/{classificationGuideId}',
            pathParams,
            bodyParam: classificationGuide
        });
    }
    updateTopic(topicId, topic, opts) {
        (0, assert_1.throwIfNotDefined)(topicId, 'topicId');
        (0, assert_1.throwIfNotDefined)(topic, 'topic');
        const pathParams = {
            topicId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv')
        };
        return this.put({
            path: '/topics/{topicId}',
            pathParams,
            queryParams,
            bodyParam: topic,
            returnType: model_1.TopicEntry
        });
    }
}
exports.ClassificationGuidesApi = ClassificationGuidesApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/gs-classification-rest-api/api/classificationGuides.api.js.map