"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ClassificationReasonsApi = void 0;
const base_api_1 = require("./base.api");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
const assert_1 = require("../../../assert");
class ClassificationReasonsApi extends base_api_1.BaseApi {
    createClassificationReason(classificationReason) {
        (0, assert_1.throwIfNotDefined)(classificationReason, 'classificationReason');
        return this.post({
            path: '/classification-reasons',
            bodyParam: classificationReason
        });
    }
    deleteClassificationReason(classificationReasonId) {
        (0, assert_1.throwIfNotDefined)(classificationReasonId, 'classificationReasonId');
        const pathParams = {
            classificationReasonId
        };
        return this.delete({
            path: '/classification-reasons/{classificationReasonId}',
            pathParams
        });
    }
    listClassificationReasons(opts) {
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/classification-reasons',
            queryParams
        });
    }
    showClassificationReasonById(classificationReasonId) {
        (0, assert_1.throwIfNotDefined)(classificationReasonId, 'classificationReasonId');
        const pathParams = {
            classificationReasonId
        };
        return this.get({
            path: '/classification-reasons/{classificationReasonId}',
            pathParams
        });
    }
    updateClassificationReason(classificationReasonId, classificationReason) {
        (0, assert_1.throwIfNotDefined)(classificationReasonId, 'classificationReasonId');
        (0, assert_1.throwIfNotDefined)(classificationReason, 'classificationReason');
        const pathParams = {
            classificationReasonId
        };
        return this.put({
            path: '/classification-reasons/{classificationReasonId}',
            pathParams,
            bodyParam: classificationReason
        });
    }
}
exports.ClassificationReasonsApi = ClassificationReasonsApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/gs-classification-rest-api/api/classificationReasons.api.js.map