"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.SecurityControlSettingsApi = void 0;
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
class SecurityControlSettingsApi extends base_api_1.BaseApi {
    getSecurityControlSetting(securityControlSettingKey) {
        (0, assert_1.throwIfNotDefined)(securityControlSettingKey, 'securityControlSettingKey');
        const pathParams = {
            securityControlSettingKey
        };
        return this.get({
            path: '/security-control-settings/{securityControlSettingKey}',
            pathParams
        });
    }
    updateSecurityControlSetting(securityControlSettingKey, securityControlSettingValue) {
        (0, assert_1.throwIfNotDefined)(securityControlSettingKey, 'securityControlSettingKey');
        (0, assert_1.throwIfNotDefined)(securityControlSettingValue, 'securityControlSettingValue');
        const pathParams = {
            securityControlSettingKey
        };
        return this.put({
            path: '/security-control-settings/{securityControlSettingKey}',
            pathParams,
            bodyParam: securityControlSettingValue
        });
    }
}
exports.SecurityControlSettingsApi = SecurityControlSettingsApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/gs-classification-rest-api/api/securityControlSettings.api.js.map