"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.SecurityMarksApi = void 0;
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
class SecurityMarksApi extends base_api_1.BaseApi {
    getSecurityMarks(securityGroupId, opts) {
        (0, assert_1.throwIfNotDefined)(securityGroupId, 'securityGroupId');
        const pathParams = {
            securityGroupId
        };
        return this.get({
            path: '/security-groups/{securityGroupId}/security-marks',
            pathParams,
            queryParams: opts
        });
    }
    createSecurityMarks(securityGroupId, securityMarkBody) {
        (0, assert_1.throwIfNotDefined)(securityGroupId, 'securityGroupId');
        (0, assert_1.throwIfNotDefined)(securityMarkBody, 'securityMarkBody');
        const pathParams = { securityGroupId };
        return this.post({
            path: '/security-groups/{securityGroupId}/security-marks',
            pathParams,
            bodyParam: securityMarkBody
        });
    }
    getSecurityMark(securityGroupId, securityMarkId) {
        (0, assert_1.throwIfNotDefined)(securityGroupId, 'securityGroupId');
        (0, assert_1.throwIfNotDefined)(securityMarkId, 'securityMarkId');
        const pathParams = {
            securityGroupId,
            securityMarkId
        };
        return this.get({
            path: '/security-groups/{securityGroupId}/security-marks/{securityMarkId}',
            pathParams
        });
    }
    updateSecurityMark(securityGroupId, securityMarkId, securityMarkBody) {
        (0, assert_1.throwIfNotDefined)(securityGroupId, 'securityGroupId');
        (0, assert_1.throwIfNotDefined)(securityMarkId, 'securityMarkId');
        (0, assert_1.throwIfNotDefined)(securityMarkBody, 'securityMarkBody');
        const pathParams = {
            securityGroupId,
            securityMarkId
        };
        return this.put({
            path: '/security-groups/{securityGroupId}/security-marks/{securityMarkId}',
            pathParams,
            bodyParam: securityMarkBody
        });
    }
    deleteSecurityMark(securityGroupId, securityMarkId) {
        (0, assert_1.throwIfNotDefined)(securityGroupId, 'securityGroupId');
        (0, assert_1.throwIfNotDefined)(securityMarkId, 'securityMarkId');
        const pathParams = {
            securityGroupId,
            securityMarkId
        };
        return this.delete({
            path: '/security-groups/{securityGroupId}/security-marks/{securityMarkId}',
            pathParams
        });
    }
}
exports.SecurityMarksApi = SecurityMarksApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/gs-classification-rest-api/api/securityMarks.api.js.map