"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.FilePlansApi = void 0;
const filePlanEntry_1 = require("../model/filePlanEntry");
const recordCategoryEntry_1 = require("../model/recordCategoryEntry");
const recordCategoryPaging_1 = require("../model/recordCategoryPaging");
const base_api_1 = require("./base.api");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
const assert_1 = require("../../../assert");
class FilePlansApi extends base_api_1.BaseApi {
    createFilePlanCategories(filePlanId, nodeBodyCreate, opts) {
        (0, assert_1.throwIfNotDefined)(filePlanId, 'filePlanId');
        (0, assert_1.throwIfNotDefined)(nodeBodyCreate, 'nodeBodyCreate');
        const pathParams = {
            filePlanId
        };
        const queryParams = {
            autoRename: opts === null || opts === void 0 ? void 0 : opts.autoRename,
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.post({
            path: '/file-plans/{filePlanId}/categories',
            pathParams,
            queryParams,
            contentTypes: ['application/json', 'multipart/form-data'],
            bodyParam: nodeBodyCreate,
            returnType: recordCategoryEntry_1.RecordCategoryEntry
        });
    }
    getFilePlan(filePlanId, opts) {
        (0, assert_1.throwIfNotDefined)(filePlanId, 'filePlanId');
        const pathParams = {
            filePlanId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/file-plans/{filePlanId}',
            pathParams,
            queryParams,
            returnType: filePlanEntry_1.FilePlanEntry
        });
    }
    getFilePlanCategories(filePlanId, opts) {
        (0, assert_1.throwIfNotDefined)(filePlanId, 'filePlanId');
        const pathParams = {
            filePlanId
        };
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            includeSource: opts === null || opts === void 0 ? void 0 : opts.includeSource,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/file-plans/{filePlanId}/categories',
            pathParams,
            queryParams,
            returnType: recordCategoryPaging_1.RecordCategoryPaging
        });
    }
    updateFilePlan(filePlanId, filePlanBodyUpdate, opts) {
        (0, assert_1.throwIfNotDefined)(filePlanId, 'filePlanId');
        (0, assert_1.throwIfNotDefined)(filePlanBodyUpdate, 'filePlanBodyUpdate');
        const pathParams = {
            filePlanId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.put({
            path: '/file-plans/{filePlanId}',
            pathParams,
            queryParams,
            bodyParam: filePlanBodyUpdate,
            returnType: filePlanEntry_1.FilePlanEntry
        });
    }
}
exports.FilePlansApi = FilePlansApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/gs-core-rest-api/api/filePlans.api.js.map