"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.LegalHoldApi = void 0;
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
const model_1 = require("./../model");
const holdBulkStatusEntry_1 = require("../model/holdBulkStatusEntry");
class LegalHoldApi extends base_api_1.BaseApi {
    getHolds(filePlanId = '-filePlan-', options) {
        (0, assert_1.throwIfNotDefined)(filePlanId, 'filePlanId');
        const pathParams = {
            filePlanId
        };
        const queryParams = {
            skipCount: options === null || options === void 0 ? void 0 : options.skipCount,
            maxItems: options === null || options === void 0 ? void 0 : options.maxItems
        };
        return this.get({
            path: '/file-plans/{filePlanId}/holds',
            pathParams,
            queryParams,
            returnType: model_1.HoldPaging
        });
    }
    assignHold(nodeId, holdId) {
        (0, assert_1.throwIfNotDefined)(holdId, 'holdId');
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        return this.post({
            path: `/holds/{holdId}/children`,
            pathParams: { holdId },
            bodyParam: [{ id: nodeId }],
            returnType: model_1.HoldEntry
        });
    }
    assignHolds(nodeIds, holdId) {
        (0, assert_1.throwIfNotDefined)(holdId, 'holdId');
        (0, assert_1.throwIfNotDefined)(nodeIds, 'nodeIds');
        return this.post({
            path: `/holds/{holdId}/children`,
            pathParams: { holdId },
            bodyParam: nodeIds,
            returnType: model_1.HoldPaging
        });
    }
    unassignHold(holdId, nodeId) {
        (0, assert_1.throwIfNotDefined)(holdId, 'holdId');
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        return this.delete({
            path: `/holds/{holdId}/children/{nodeId}`,
            pathParams: { holdId, nodeId }
        });
    }
    createHold(filePlanId, hold) {
        (0, assert_1.throwIfNotDefined)(filePlanId, 'filePlanId');
        (0, assert_1.throwIfNotDefined)(hold, 'hold');
        const pathParams = {
            filePlanId
        };
        return this.post({
            path: '/file-plans/{filePlanId}/holds',
            pathParams,
            bodyParam: [hold],
            returnType: model_1.HoldEntry
        });
    }
    createHolds(filePlanId = '-filePlan-', holds) {
        (0, assert_1.throwIfNotDefined)(filePlanId, 'filePlanId');
        (0, assert_1.throwIfNotDefined)(holds, 'holds');
        const pathParams = {
            filePlanId
        };
        return this.post({
            path: '/file-plans/{filePlanId}/holds',
            pathParams,
            bodyParam: holds,
            returnType: model_1.HoldPaging
        });
    }
    bulkAssignHold(holdId, query) {
        (0, assert_1.throwIfNotDefined)(holdId, 'holdId');
        (0, assert_1.throwIfNotDefined)(query, 'query');
        return this.post({
            path: `/holds/{holdId}/bulk`,
            pathParams: { holdId },
            bodyParam: {
                query,
                op: 'ADD'
            }
        });
    }
    getBulkStatus(bulkStatusId, holdId) {
        (0, assert_1.throwIfNotDefined)(holdId, 'holdId');
        (0, assert_1.throwIfNotDefined)(bulkStatusId, 'bulkStatusId');
        return this.get({
            path: `/holds/{holdId}/bulk-statuses/{bulkStatusId}`,
            pathParams: { holdId, bulkStatusId },
            returnType: holdBulkStatusEntry_1.HoldBulkStatusEntry
        });
    }
}
exports.LegalHoldApi = LegalHoldApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/gs-core-rest-api/api/legal-hold.api.js.map