"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.RecordCategoriesApi = void 0;
const model_1 = require("../model");
const base_api_1 = require("./base.api");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
const assert_1 = require("../../../assert");
class RecordCategoriesApi extends base_api_1.BaseApi {
    createRecordCategoryChild(recordCategoryId, nodeBodyCreate, opts) {
        (0, assert_1.throwIfNotDefined)(recordCategoryId, 'recordCategoryId');
        (0, assert_1.throwIfNotDefined)(nodeBodyCreate, 'nodeBodyCreate');
        const pathParams = {
            recordCategoryId
        };
        const queryParams = {
            autoRename: opts === null || opts === void 0 ? void 0 : opts.autoRename,
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.post({
            path: '/record-categories/{recordCategoryId}/children',
            pathParams,
            queryParams,
            bodyParam: nodeBodyCreate,
            returnType: model_1.RecordCategoryChildEntry
        });
    }
    deleteRecordCategory(recordCategoryId) {
        (0, assert_1.throwIfNotDefined)(recordCategoryId, 'recordCategoryId');
        const pathParams = {
            recordCategoryId
        };
        return this.delete({
            path: '/record-categories/{recordCategoryId}',
            pathParams
        });
    }
    getRecordCategory(recordCategoryId, opts) {
        (0, assert_1.throwIfNotDefined)(recordCategoryId, 'recordCategoryId');
        const pathParams = {
            recordCategoryId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            relativePath: opts === null || opts === void 0 ? void 0 : opts.relativePath,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/record-categories/{recordCategoryId}',
            pathParams,
            queryParams,
            returnType: model_1.RecordCategoryEntry
        });
    }
    listRecordCategoryChildren(recordCategoryId, opts) {
        (0, assert_1.throwIfNotDefined)(recordCategoryId, 'recordCategoryId');
        const pathParams = {
            recordCategoryId
        };
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            where: opts === null || opts === void 0 ? void 0 : opts.where,
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            relativePath: opts === null || opts === void 0 ? void 0 : opts.relativePath,
            includeSource: opts === null || opts === void 0 ? void 0 : opts.includeSource,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/record-categories/{recordCategoryId}/children',
            pathParams,
            queryParams,
            returnType: model_1.RecordCategoryChildPaging
        });
    }
    updateRecordCategory(recordCategoryId, recordCategoryBodyUpdate, opts) {
        (0, assert_1.throwIfNotDefined)(recordCategoryId, 'recordCategoryId');
        (0, assert_1.throwIfNotDefined)(recordCategoryBodyUpdate, 'recordCategoryBodyUpdate');
        const pathParams = {
            recordCategoryId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.put({
            path: '/record-categories/{recordCategoryId}',
            pathParams,
            queryParams,
            bodyParam: recordCategoryBodyUpdate,
            returnType: model_1.RecordCategoryEntry
        });
    }
}
exports.RecordCategoriesApi = RecordCategoriesApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/gs-core-rest-api/api/recordCategories.api.js.map