"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.RecordFoldersApi = void 0;
const model_1 = require("../model");
const base_api_1 = require("./base.api");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
const assert_1 = require("../../../assert");
class RecordFoldersApi extends base_api_1.BaseApi {
    createRecordFolderChild(recordFolderId, recordBodyCreate, opts) {
        (0, assert_1.throwIfNotDefined)(recordFolderId, 'recordFolderId');
        (0, assert_1.throwIfNotDefined)(recordBodyCreate, 'recordBodyCreate');
        const pathParams = {
            recordFolderId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.post({
            path: '/record-folders/{recordFolderId}/records',
            pathParams,
            queryParams,
            bodyParam: recordBodyCreate,
            returnType: model_1.RecordEntry
        });
    }
    deleteRecordFolder(recordFolderId) {
        (0, assert_1.throwIfNotDefined)(recordFolderId, 'recordFolderId');
        const pathParams = {
            recordFolderId
        };
        return this.delete({
            path: '/record-folders/{recordFolderId}',
            pathParams
        });
    }
    getRecordFolder(recordFolderId, opts) {
        (0, assert_1.throwIfNotDefined)(recordFolderId, 'recordFolderId');
        const pathParams = {
            recordFolderId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/record-folders/{recordFolderId}',
            pathParams,
            queryParams,
            returnType: model_1.RecordFolderEntry
        });
    }
    listRecordFolderChildren(recordFolderId, opts) {
        (0, assert_1.throwIfNotDefined)(recordFolderId, 'recordFolderId');
        const pathParams = {
            recordFolderId
        };
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            where: opts === null || opts === void 0 ? void 0 : opts.where,
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            includeSource: opts === null || opts === void 0 ? void 0 : opts.includeSource,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/record-folders/{recordFolderId}/records',
            pathParams,
            queryParams,
            returnType: model_1.RecordFolderAssociationPaging
        });
    }
    updateRecordFolder(recordFolderId, recordFolderBodyUpdate, opts) {
        (0, assert_1.throwIfNotDefined)(recordFolderId, 'recordFolderId');
        (0, assert_1.throwIfNotDefined)(recordFolderBodyUpdate, 'recordFolderBodyUpdate');
        const pathParams = {
            recordFolderId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.put({
            path: '/record-folders/{recordFolderId}',
            pathParams,
            queryParams,
            bodyParam: recordFolderBodyUpdate,
            returnType: model_1.RecordFolderEntry
        });
    }
}
exports.RecordFoldersApi = RecordFoldersApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/gs-core-rest-api/api/recordFolders.api.js.map