"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.RecordsApi = void 0;
const recordEntry_1 = require("../model/recordEntry");
const base_api_1 = require("./base.api");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
const assert_1 = require("../../../assert");
class RecordsApi extends base_api_1.BaseApi {
    completeRecord(recordId, opts) {
        (0, assert_1.throwIfNotDefined)(recordId, 'recordId');
        const pathParams = {
            recordId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.post({
            path: '/records/{recordId}/complete',
            pathParams,
            queryParams,
            returnType: recordEntry_1.RecordEntry
        });
    }
    deleteRecord(recordId) {
        (0, assert_1.throwIfNotDefined)(recordId, 'recordId');
        const pathParams = {
            recordId
        };
        return this.delete({
            path: '/records/{recordId}',
            pathParams
        });
    }
    fileRecord(recordId, nodeBodyFile, opts) {
        (0, assert_1.throwIfNotDefined)(recordId, 'recordId');
        (0, assert_1.throwIfNotDefined)(nodeBodyFile, 'nodeBodyFile');
        const pathParams = {
            recordId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.post({
            path: '/records/{recordId}/file',
            pathParams,
            queryParams,
            bodyParam: nodeBodyFile,
            returnType: recordEntry_1.RecordEntry
        });
    }
    getRecord(recordId, opts) {
        (0, assert_1.throwIfNotDefined)(recordId, 'recordId');
        const pathParams = {
            recordId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/records/{recordId}',
            pathParams,
            queryParams,
            returnType: recordEntry_1.RecordEntry
        });
    }
    getRecordContent(recordId, opts) {
        (0, assert_1.throwIfNotDefined)(recordId, 'recordId');
        const pathParams = {
            recordId
        };
        const queryParams = {
            attachment: opts === null || opts === void 0 ? void 0 : opts.attachment
        };
        const headerParams = {
            'If-Modified-Since': opts === null || opts === void 0 ? void 0 : opts.ifModifiedSince
        };
        return this.get({
            path: '/records/{recordId}/content',
            pathParams,
            queryParams,
            headerParams
        });
    }
    updateRecord(recordId, recordBodyUpdate, opts) {
        (0, assert_1.throwIfNotDefined)(recordId, 'recordId');
        (0, assert_1.throwIfNotDefined)(recordBodyUpdate, 'recordBodyUpdate');
        const pathParams = {
            recordId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.put({
            path: '/records/{recordId}',
            pathParams,
            queryParams,
            bodyParam: recordBodyUpdate,
            returnType: recordEntry_1.RecordEntry
        });
    }
}
exports.RecordsApi = RecordsApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/gs-core-rest-api/api/records.api.js.map