"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.TransferContainersApi = void 0;
const transferContainerAssociationPaging_1 = require("../model/transferContainerAssociationPaging");
const transferContainerEntry_1 = require("../model/transferContainerEntry");
const base_api_1 = require("./base.api");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
const assert_1 = require("../../../assert");
class TransferContainersApi extends base_api_1.BaseApi {
    getTransferContainer(transferContainerId, opts) {
        (0, assert_1.throwIfNotDefined)(transferContainerId, 'transferContainerId');
        const pathParams = {
            transferContainerId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/transfer-containers/{transferContainerId}',
            pathParams,
            queryParams,
            returnType: transferContainerEntry_1.TransferContainerEntry
        });
    }
    listTransfers(transferContainerId, opts) {
        (0, assert_1.throwIfNotDefined)(transferContainerId, 'transferContainerId');
        opts = opts || {};
        const pathParams = {
            transferContainerId
        };
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            includeSource: opts === null || opts === void 0 ? void 0 : opts.includeSource,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/transfer-containers/{transferContainerId}/transfers',
            pathParams,
            queryParams,
            returnType: transferContainerAssociationPaging_1.TransferContainerAssociationPaging
        });
    }
    updateTransferContainer(transferContainerId, nodeBodyUpdate, opts) {
        (0, assert_1.throwIfNotDefined)(transferContainerId, 'transferContainerId');
        (0, assert_1.throwIfNotDefined)(nodeBodyUpdate, 'nodeBodyUpdate');
        opts = opts || {};
        const pathParams = {
            transferContainerId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.put({
            path: '/transfer-containers/{transferContainerId}',
            pathParams,
            queryParams,
            bodyParam: nodeBodyUpdate,
            returnType: transferContainerEntry_1.TransferContainerEntry
        });
    }
}
exports.TransferContainersApi = TransferContainersApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/gs-core-rest-api/api/transferContainers.api.js.map