"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.UnfiledContainersApi = void 0;
const model_1 = require("../model");
const base_api_1 = require("./base.api");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
const assert_1 = require("../../../assert");
class UnfiledContainersApi extends base_api_1.BaseApi {
    createUnfiledContainerChildren(unfiledContainerId, nodeBodyCreate, opts) {
        (0, assert_1.throwIfNotDefined)(unfiledContainerId, 'unfiledContainerId');
        (0, assert_1.throwIfNotDefined)(nodeBodyCreate, 'nodeBodyCreate');
        const pathParams = {
            unfiledContainerId
        };
        const queryParams = {
            autoRename: opts === null || opts === void 0 ? void 0 : opts.autoRename,
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        const contentTypes = ['application/json', 'multipart/form-data'];
        return this.post({
            path: '/unfiled-containers/{unfiledContainerId}/children',
            pathParams,
            queryParams,
            contentTypes,
            bodyParam: nodeBodyCreate,
            returnType: model_1.UnfiledContainerAssociationPaging
        });
    }
    getUnfiledContainer(unfiledContainerId, opts) {
        (0, assert_1.throwIfNotDefined)(unfiledContainerId, 'unfiledContainerId');
        const pathParams = {
            unfiledContainerId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/unfiled-containers/{unfiledContainerId}',
            pathParams,
            queryParams,
            returnType: model_1.UnfiledContainerEntry
        });
    }
    listUnfiledContainerChildren(unfiledContainerId, opts) {
        (0, assert_1.throwIfNotDefined)(unfiledContainerId, 'unfiledContainerId');
        const pathParams = {
            unfiledContainerId
        };
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            where: opts === null || opts === void 0 ? void 0 : opts.where,
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            includeSource: opts === null || opts === void 0 ? void 0 : opts.includeSource,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/unfiled-containers/{unfiledContainerId}/children',
            pathParams,
            queryParams,
            returnType: model_1.UnfiledContainerAssociationPaging
        });
    }
    updateUnfiledContainer(unfiledContainerId, unfiledContainerBodyUpdate, opts) {
        (0, assert_1.throwIfNotDefined)(unfiledContainerId, 'unfiledContainerId');
        (0, assert_1.throwIfNotDefined)(unfiledContainerBodyUpdate, 'unfiledContainerBodyUpdate');
        const pathParams = {
            unfiledContainerId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.put({
            path: '/unfiled-containers/{unfiledContainerId}',
            pathParams,
            queryParams,
            bodyParam: unfiledContainerBodyUpdate,
            returnType: model_1.UnfiledContainerEntry
        });
    }
}
exports.UnfiledContainersApi = UnfiledContainersApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/gs-core-rest-api/api/unfiledContainers.api.js.map