"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.UnfiledRecordFoldersApi = void 0;
const unfiledRecordFolderAssociationPaging_1 = require("../model/unfiledRecordFolderAssociationPaging");
const unfiledRecordFolderEntry_1 = require("../model/unfiledRecordFolderEntry");
const base_api_1 = require("./base.api");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
const assert_1 = require("../../../assert");
class UnfiledRecordFoldersApi extends base_api_1.BaseApi {
    createUnfiledRecordFolderChildren(unfiledRecordFolderId, nodeBodyCreate, opts) {
        (0, assert_1.throwIfNotDefined)(unfiledRecordFolderId, 'unfiledRecordFolderId');
        (0, assert_1.throwIfNotDefined)(nodeBodyCreate, 'nodeBodyCreate');
        const pathParams = {
            unfiledRecordFolderId
        };
        const queryParams = {
            autoRename: opts === null || opts === void 0 ? void 0 : opts.autoRename,
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.post({
            path: '/unfiled-record-folders/{unfiledRecordFolderId}/children',
            pathParams,
            queryParams,
            bodyParam: nodeBodyCreate,
            contentTypes: ['application/json', 'multipart/form-data'],
            returnType: unfiledRecordFolderAssociationPaging_1.UnfiledRecordFolderAssociationPaging
        });
    }
    deleteUnfiledRecordFolder(unfiledRecordFolderId) {
        (0, assert_1.throwIfNotDefined)(unfiledRecordFolderId, 'unfiledRecordFolderId');
        const pathParams = {
            unfiledRecordFolderId
        };
        return this.delete({
            path: '/unfiled-record-folders/{unfiledRecordFolderId}',
            pathParams
        });
    }
    getUnfiledRecordFolder(unfiledRecordFolderId, opts) {
        (0, assert_1.throwIfNotDefined)(unfiledRecordFolderId, 'unfiledRecordFolderId');
        const pathParams = {
            unfiledRecordFolderId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            relativePath: opts === null || opts === void 0 ? void 0 : opts.relativePath,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/unfiled-record-folders/{unfiledRecordFolderId}',
            pathParams,
            queryParams,
            returnType: unfiledRecordFolderEntry_1.UnfiledRecordFolderEntry
        });
    }
    listUnfiledRecordFolderChildren(unfiledRecordFolderId, opts) {
        (0, assert_1.throwIfNotDefined)(unfiledRecordFolderId, 'unfiledRecordFolderId');
        opts = opts || {};
        const pathParams = {
            unfiledRecordFolderId
        };
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            where: opts === null || opts === void 0 ? void 0 : opts.where,
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            relativePath: opts === null || opts === void 0 ? void 0 : opts.relativePath,
            includeSource: opts === null || opts === void 0 ? void 0 : opts.includeSource,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/unfiled-record-folders/{unfiledRecordFolderId}/children',
            pathParams,
            queryParams,
            returnType: unfiledRecordFolderAssociationPaging_1.UnfiledRecordFolderAssociationPaging
        });
    }
    updateUnfiledRecordFolder(unfiledRecordFolderId, unfiledRecordFolderBodyUpdate, opts) {
        (0, assert_1.throwIfNotDefined)(unfiledRecordFolderId, 'unfiledRecordFolderId');
        (0, assert_1.throwIfNotDefined)(unfiledRecordFolderBodyUpdate, 'unfiledRecordFolderBodyUpdate');
        const pathParams = {
            unfiledRecordFolderId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            includeSource: opts === null || opts === void 0 ? void 0 : opts.includeSource,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.put({
            path: '/unfiled-record-folders/{unfiledRecordFolderId}',
            pathParams,
            queryParams,
            bodyParam: unfiledRecordFolderBodyUpdate,
            returnType: unfiledRecordFolderEntry_1.UnfiledRecordFolderEntry
        });
    }
}
exports.UnfiledRecordFoldersApi = UnfiledRecordFoldersApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/gs-core-rest-api/api/unfiledRecordFolders.api.js.map