"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.PredictionsApi = void 0;
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
const model_1 = require("../model");
class PredictionsApi extends base_api_1.BaseApi {
    getPredictions(nodeId) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        const pathParams = {
            nodeId
        };
        return this.get({
            path: '/nodes/{nodeId}/predictions',
            pathParams,
            returnType: model_1.PredictionPaging
        });
    }
    reviewPrediction(predictionId, reviewStatus) {
        (0, assert_1.throwIfNotDefined)(predictionId, 'predictionId');
        (0, assert_1.throwIfNotDefined)(reviewStatus, 'reviewStatus');
        const pathParams = {
            predictionId,
            reviewStatus
        };
        return this.post({
            path: '/predictions/{predictionId}/review',
            pathParams,
            returnType: (Promise)
        });
    }
}
exports.PredictionsApi = PredictionsApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/hxi-connector-api/api/predictions.api.js.map