"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.AspectsApi = exports.ListAspectsOpts = void 0;
const aspectEntry_1 = require("../model/aspectEntry");
const aspectPaging_1 = require("../model/aspectPaging");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
class ListAspectsOpts {
}
exports.ListAspectsOpts = ListAspectsOpts;
class AspectsApi extends base_api_1.BaseApi {
    getAspect(aspectId) {
        (0, assert_1.throwIfNotDefined)(aspectId, 'aspectId');
        const pathParams = {
            aspectId
        };
        return this.get({
            path: '/aspects/{aspectId}',
            pathParams,
            returnType: aspectEntry_1.AspectEntry
        });
    }
    listAspects(opts) {
        const queryParams = {
            where: opts === null || opts === void 0 ? void 0 : opts.where,
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv')
        };
        return this.get({
            path: '/aspects',
            queryParams,
            returnType: aspectPaging_1.AspectPaging
        });
    }
}
exports.AspectsApi = AspectsApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/model-rest-api/api/aspects.api.js.map