"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.TypesApi = void 0;
const typeEntry_1 = require("../model/typeEntry");
const typePaging_1 = require("../model/typePaging");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
class TypesApi extends base_api_1.BaseApi {
    getType(typeId) {
        (0, assert_1.throwIfNotDefined)(typeId, 'typeId');
        const pathParams = {
            typeId
        };
        return this.get({
            path: '/types/{typeId}',
            pathParams,
            returnType: typeEntry_1.TypeEntry
        });
    }
    listTypes(opts) {
        const queryParams = {
            where: opts === null || opts === void 0 ? void 0 : opts.where,
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv')
        };
        return this.get({
            path: '/types',
            queryParams,
            returnType: typePaging_1.TypePaging
        });
    }
}
exports.TypesApi = TypesApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/model-rest-api/api/types.api.js.map