/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { GlobalDateFormatRepresentation, PasswordValidationConstraints, SystemPropertiesRepresentation } from '../model';
import { BaseApi } from './base.api';
/**
 * SystemPropertiesApi service.
 */
export declare class SystemPropertiesApi extends BaseApi {
    /**
     * Get global date format
     * @param tenantId tenantId
     * @return Promise<GlobalDateFormatRepresentation>
     */
    getGlobalDateFormat(tenantId: number): Promise<GlobalDateFormatRepresentation>;
    /**
     * Get password validation constraints
     * @param tenantId tenantId
     * @return Promise<PasswordValidationConstraints>
     */
    getPasswordValidationConstraints(tenantId: number): Promise<PasswordValidationConstraints>;
    /**
     * Retrieve system properties
     *
     * Typical value is AllowInvolveByEmail
     * @return Promise<SystemPropertiesRepresentation>
     */
    getProperties(): Promise<SystemPropertiesRepresentation>;
    /**
     * Get involved users who can edit forms
     * @param tenantId tenantId
     * @return Promise<boolean>
     */
    involvedUsersCanEditForms(tenantId: number): Promise<boolean>;
}
