/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { ResultListDataRepresentationUserProcessInstanceFilterRepresentation, ResultListDataRepresentationUserTaskFilterRepresentation, UserFilterOrderRepresentation, UserProcessInstanceFilterRepresentation, UserTaskFilterRepresentation } from '../model';
import { BaseApi } from './base.api';
import { AppIdQuery } from './types';
/**
 * UserFiltersApi service.
 */
export declare class UserFiltersApi extends BaseApi {
    /**
     * Create a process instance filter
     * @param userProcessInstanceFilterRepresentation userProcessInstanceFilterRepresentation
     * @returns Promise<UserProcessInstanceFilterRepresentation>
     */
    createUserProcessInstanceFilter(userProcessInstanceFilterRepresentation: UserProcessInstanceFilterRepresentation): Promise<UserProcessInstanceFilterRepresentation>;
    /**
     * Create a task filter
     * @param userTaskFilterRepresentation userTaskFilterRepresentation
     * @returns Promise<UserTaskFilterRepresentation>
     */
    createUserTaskFilter(userTaskFilterRepresentation: UserTaskFilterRepresentation): Promise<UserTaskFilterRepresentation>;
    /**
     * Delete a process instance filter
     * @param userFilterId userFilterId
     * @returns Promise<{}>
     */
    deleteUserProcessInstanceFilter(userFilterId: number): Promise<void>;
    /**
     * Delete a task filter
     * @param userFilterId userFilterId
     * @returns Promise<{}>
     */
    deleteUserTaskFilter(userFilterId: number): Promise<void>;
    /**
     * Get a process instance filter
     * @param userFilterId userFilterId
     * @returns Promise<UserProcessInstanceFilterRepresentation>
     */
    getUserProcessInstanceFilter(userFilterId: number): Promise<UserProcessInstanceFilterRepresentation>;
    /**
     * List process instance filters
     *
     * Returns filters for the current user, optionally filtered by *appId*.
     * @param opts Optional parameters
     * @returns Promise<ResultListDataRepresentationUserProcessInstanceFilterRepresentation>
     */
    getUserProcessInstanceFilters(opts?: AppIdQuery): Promise<ResultListDataRepresentationUserProcessInstanceFilterRepresentation>;
    /**
     * Get a task filter
     * @param userFilterId userFilterId
     * @returns Promise<UserTaskFilterRepresentation>
     */
    getUserTaskFilter(userFilterId: number): Promise<UserTaskFilterRepresentation>;
    /**
     * List task filters
     *
     * Returns filters for the current user, optionally filtered by *appId*.
     * @param opts Optional parameters
     * @returns Promise<ResultListDataRepresentationUserTaskFilterRepresentation>
     */
    getUserTaskFilters(opts?: AppIdQuery): Promise<ResultListDataRepresentationUserTaskFilterRepresentation>;
    /**
     * Re-order the list of user process instance filters
     * @param filterOrderRepresentation filterOrderRepresentation
     * @returns Promise<{}>
     */
    orderUserProcessInstanceFilters(filterOrderRepresentation: UserFilterOrderRepresentation): Promise<any>;
    /**
     * Re-order the list of user task filters
     * @param filterOrderRepresentation filterOrderRepresentation
     * @returns Promise<{}>
     */
    orderUserTaskFilters(filterOrderRepresentation: UserFilterOrderRepresentation): Promise<any>;
    /**
     * Update a process instance filter
     * @param userFilterId userFilterId
     * @param userProcessInstanceFilterRepresentation userProcessInstanceFilterRepresentation
     * @returns Promise<UserProcessInstanceFilterRepresentation>
     */
    updateUserProcessInstanceFilter(userFilterId: number, userProcessInstanceFilterRepresentation: UserProcessInstanceFilterRepresentation): Promise<UserProcessInstanceFilterRepresentation>;
    /**
     * Update a task filter
     * @param userFilterId userFilterId
     * @param userTaskFilterRepresentation userTaskFilterRepresentation
     * @returns Promise<UserTaskFilterRepresentation>
     */
    updateUserTaskFilter(userFilterId: number, userTaskFilterRepresentation: UserTaskFilterRepresentation): Promise<UserTaskFilterRepresentation>;
}
