/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { ResetPasswordRepresentation } from '../model/resetPasswordRepresentation';
import { ResultListDataRepresentationLightUserRepresentation } from '../model/resultListDataRepresentationLightUserRepresentation';
import { UserActionRepresentation } from '../model/userActionRepresentation';
import { UserRepresentation } from '../model/userRepresentation';
import { BaseApi } from './base.api';
export type GetUsersQuery = {
    filter?: string;
    email?: string;
    externalId?: string;
    externalIdCaseInsensitive?: string;
    excludeTaskId?: string;
    excludeProcessId?: string;
    groupId?: number;
    tenantId?: number;
};
/**
 * Users service.
 */
export declare class UsersApi extends BaseApi {
    /**
     * Execute an action for a specific user
     *
     * Typical action is updating/reset password
     * @param userId userId
     * @param actionRequest actionRequest
     * @returns Promise<{}>
     */
    executeAction(userId: number, actionRequest: UserActionRepresentation): Promise<any>;
    /**
     * Stream user profile picture
     * @param userId userId
     * @returns Promise<{}>
     */
    getUserProfilePictureUrl(userId: string): string;
    /**
     * Get a user
     * @param userId userId
     * @returns Promise<UserRepresentation>
     */
    getUser(userId: number): Promise<UserRepresentation>;
    /**
     * Query users
     *
     * A common use case is that a user wants to select another user (eg. when assigning a task) or group.
     * @param opts Optional parameters
     * @returns Promise<ResultListDataRepresentationLightUserRepresentation>
     */
    getUsers(opts?: GetUsersQuery): Promise<ResultListDataRepresentationLightUserRepresentation>;
    /**
     * Request a password reset
     * @param resetPassword resetPassword
     * @returns Promise<{}>
     */
    requestPasswordReset(resetPassword: ResetPasswordRepresentation): Promise<any>;
    /**
     * Update a user
     * @param userId userId
     * @param userRequest userRequest
     * @returns Promise<UserRepresentation>
     */
    updateUser(userId: number, userRequest: UserRepresentation): Promise<UserRepresentation>;
}
