/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
export declare class DateAlfresco extends Date {
    /**
     * Parses an ISO-8601 string representation of a date value.
     * @param  dateToConvert The date value as a string.
     * @returns  The parsed date object.
     */
    static parseDate(dateToConvert: any): Date;
    /**
     * Parses the date component of a ISO-8601 string representation of a date value.
     * @param dateToConvert The date value as a string.
     * @returns The parsed date object.
     */
    static parseDateTime(dateToConvert: string): Date;
    /**
     * Parses the timezone component of a ISO-8601 string representation of a date value.
     * @param dateToConvert The timezone offset as a string, e.g. '+0000', '+2000' or '-0500'.
     * @returns The number of minutes offset from UTC.
     */
    static parseDateTimeZone(dateToConvert: string): number;
}
