/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { FilePlanBodyUpdate } from '../model/filePlanBodyUpdate';
import { FilePlanEntry } from '../model/filePlanEntry';
import { RecordCategoryEntry } from '../model/recordCategoryEntry';
import { RecordCategoryPaging } from '../model/recordCategoryPaging';
import { RootCategoryBodyCreate } from '../model/rootCategoryBodyCreate';
import { BaseApi } from './base.api';
import { RecordsIncludeQuery, RecordsPagingQuery, RecordsSourceQuery } from './types';
/**
 * FilePlansApi service.
 */
export declare class FilePlansApi extends BaseApi {
    /**
     * Create record categories for a file plan
     * @param filePlanId The identifier of a file plan. You can also use the -filePlan- alias.
     * @param nodeBodyCreate The node information to create.
     * @param opts Optional parameters
     * @param opts.autoRename If `true`, then  a name clash will cause an attempt to auto rename by finding a unique name using an integer suffix.
     * @returns Promise<RecordCategoryEntry>
     */
    createFilePlanCategories(filePlanId: string, nodeBodyCreate: RootCategoryBodyCreate, opts?: {
        autoRename?: boolean;
    } & RecordsIncludeQuery): Promise<RecordCategoryEntry>;
    /**
     * Get a file plan
     *
     * Mandatory fields and the file plan's aspects and properties are returned by default.
     * You can use the **include** parameter (include=allowableOperations) to return additional information.
     * @param filePlanId The identifier of a file plan. You can also use the -filePlan- alias.
     * @param opts Optional parameters
     * @returns Promise<FilePlanEntry>
     */
    getFilePlan(filePlanId: string, opts?: RecordsIncludeQuery): Promise<FilePlanEntry>;
    /**
     * List file plans's children
     *
     * Minimal information for each child is returned by default.
     * You can use the **include** parameter (include=allowableOperations) to return additional information.
     * @param filePlanId The identifier of a file plan. You can also use the -filePlan- alias.
     * @param opts Optional parameters
     * @returns Promise<RecordCategoryPaging>
     */
    getFilePlanCategories(filePlanId: string, opts?: RecordsIncludeQuery & RecordsPagingQuery & RecordsSourceQuery): Promise<RecordCategoryPaging>;
    /**
     * Update a file plan
     *
     * **Note:** Currently there is no optimistic locking for updates, so they are applied in \"last one wins\" order.
     * @param filePlanId The identifier of a file plan. You can also use the -filePlan- alias.
     * @param filePlanBodyUpdate The file plan information to update.
     * @param opts Optional parameters
     * @returns Promise<FilePlanEntry>
     */
    updateFilePlan(filePlanId: string, filePlanBodyUpdate: FilePlanBodyUpdate, opts?: RecordsIncludeQuery): Promise<FilePlanEntry>;
}
