/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { TransferContainerAssociationPaging } from '../model/transferContainerAssociationPaging';
import { TransferContainerBodyUpdate } from '../model/transferContainerBodyUpdate';
import { TransferContainerEntry } from '../model/transferContainerEntry';
import { BaseApi } from './base.api';
import { RecordsIncludeQuery, RecordsPagingQuery, RecordsSourceQuery } from './types';
/**
 * TransferContainersApi service.
 */
export declare class TransferContainersApi extends BaseApi {
    /**
     * Get a transfer container
     *
     * Mandatory fields and the transfer container's aspects and properties are returned by default.
     * You can use the **include** parameter (include=allowableOperations) to return additional information.
     * @param transferContainerId The identifier of a transfer container. You can also use the -transfers- alias.
     * @param opts Optional parameters
     * @returns Promise<TransferContainerEntry>
     */
    getTransferContainer(transferContainerId: string, opts?: RecordsIncludeQuery): Promise<TransferContainerEntry>;
    /**
     * List transfer container's children
     *
     * Minimal information for each child is returned by default.
     * You can use the **include** parameter (include=allowableOperations) to return additional information.
     * @param transferContainerId The identifier of a transfer container. You can also use the -transfers- alias.
     * @param opts Optional parameters
     * @returns Promise<TransferContainerAssociationPaging>
     */
    listTransfers(transferContainerId: string, opts?: RecordsSourceQuery & RecordsIncludeQuery & RecordsPagingQuery): Promise<TransferContainerAssociationPaging>;
    /**
     * Update transfer container
     * @param transferContainerId The identifier of a transfer container. You can also use the -transfers- alias.
     * @param nodeBodyUpdate The node information to update.
     * @param opts Optional parameters
     * @returns Promise<TransferContainerEntry>
     */
    updateTransferContainer(transferContainerId: string, nodeBodyUpdate: TransferContainerBodyUpdate, opts?: RecordsIncludeQuery): Promise<TransferContainerEntry>;
}
