/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { AspectEntry } from '../model/aspectEntry';
import { AspectPaging } from '../model/aspectPaging';
import { BaseApi } from './base.api';
export declare class ListAspectsOpts {
    /**
     * Optionally filter the list. Here are some examples:
     *
     * An aspect should be represented in the following format(prefix:name). e.g 'cm:title'.
     *
     * The following where clause will only return aspects from the namespace1:model and namespace2:model.
     *
     *   - where=(modelId in ('namespace1:model','namespace2:model'))
     *   - where=(modelId in ('namespace1:model INCLUDESUBASPECTS','namespace2:model'))
     *
     * The following where clause will only return sub aspects for the given parents.
     *
     *   - where=(parentId in ('namespace1:parent','namespace2:parent'))
     *
     * The following where clause will only return aspects that match the pattern.
     *
     *   - where=(namespaceUri matches('http://www.alfresco.*'))
     *
     * The following where clause will only return aspects that don't match the pattern.
     *
     *   - where=(not namespaceUri matches('http://www.alfresco.*'))
     */
    where?: string;
    skipCount?: number;
    maxItems?: number;
    /**
     * Returns additional information about the aspect. The following optional fields can be requested:
     * - properties
     * - mandatoryAspects
     * - associations
     */
    include?: string[];
}
/**
 * Aspects service.
 */
export declare class AspectsApi extends BaseApi {
    /**
     * Get an aspect
     *
     * **Note:** This is available in Alfresco 7.0.0 and newer versions.
     * @param aspectId The `Qname` of an aspect(prefix:name) e.g 'cm:title'
     * @returns Promise<AspectEntry>
     */
    getAspect(aspectId: string): Promise<AspectEntry>;
    /**
     * List aspects
     *
     * **Note:** This is available in Alfresco 7.0.0 and newer versions.
     * @param opts Optional parameters
     * @returns Promise<AspectPaging>
     */
    listAspects(opts?: ListAspectsOpts): Promise<AspectPaging>;
}
