/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { AlfrescoApiClient, AlfrescoApiClientPromise } from '../alfrescoApiClient';
import { AlfrescoApiConfig } from '../alfrescoApiConfig';
import { Authentication } from './authentication';
import { HttpClient } from '../api-clients/http-client.interface';
export declare class ProcessAuth extends AlfrescoApiClient {
    ticket: string;
    authentications: Authentication;
    constructor(config: AlfrescoApiConfig, httpClient?: HttpClient);
    setConfig(config: AlfrescoApiConfig): void;
    changeHost(): void;
    changeCsrfConfig(disableCsrf: boolean): void;
    saveUsername(username: string): void;
    /**
     * login Activiti API
     * @param username Username to login
     * @param password Password to login
     * @returns A promise that returns {new authentication ticket} if resolved and {error} if rejected.
     */
    login(username: string, password: string): AlfrescoApiClientPromise<string>;
    /**
     * logout Alfresco API
     * @returns A promise that returns {new authentication ticket} if resolved and {error} if rejected.
     */
    logout(): AlfrescoApiClientPromise<void>;
    /**
     * Set the current Ticket
     * @param ticket Ticket value
     */
    setTicket(ticket: string): void;
    invalidateSession(): void;
    /**
     * Get the current Ticket
     * @returns ticket
     */
    getTicket(): string;
    /**
     * If the client is logged in return true
     * @returns `true` if logged in, otherwise `false`
     */
    isLoggedIn(): boolean;
    /**
     * return the Authentication
     * @returns authentication object
     */
    getAuthentication(): Authentication;
}
